###############################################################################
## Results for Table A6
###############################################################################

rm(list = ls())

#-------------------------------------------------------------------------------
# Data
#-------------------------------------------------------------------------------

data <- matrix(c(67,123,39,434,39.4,23.4,22.3,23.1,277.8,220.3,91.6,241.3),nrow=4)
data

#-------------------------------------------------------------------------------
# Variance function
#-------------------------------------------------------------------------------

varfun <- function(sigma2_1,sigma2_0,G,nbar,nvar,p1,q1,q0,rho1,rho0){
  DE1 <- 1+rho1*p1*(nvar/nbar+nbar-1)
  DE0 <- 1+rho0*(nvar/nbar+nbar-1)
  V <- DE1*sigma2_1/(G*nbar*p1*q1)+DE0*sigma2_0/(G*nbar*q0)
  return(V)
}

#-------------------------------------------------------------------------------
# Power function
#-------------------------------------------------------------------------------

powerfun <- function(V,tau,alpha){
  beta <- 1-pnorm(tau/sqrt(V)+qnorm(1-alpha/2))+pnorm(tau/sqrt(V)-qnorm(1-alpha/2))
}

#-------------------------------------------------------------------------------
# Function to calculate optimal group probabilities
#-------------------------------------------------------------------------------

qopt <- function(pt,sigma2_00,sigma2_0t,sigma2_1t,rho_00,rho_0t,rho_1t,nbar,nvar){
  M <- length(pt)-1
  B0 <- sigma2_00*(1+rho_00*(nvar/nbar+nbar-1))
  Bt <- sigma2_1t*(1+rho_1t*(nvar/nbar+nbar-1)*pt[-1])/pt[-1] + sigma2_0t*(1+rho_0t*(nvar/nbar+nbar-1)*(1-pt[-1]))/(1-pt[-1])
  q0 <- sqrt(2*M*B0)/(sqrt(2*M*B0)+sum(sqrt(Bt)))
  qt <- sqrt(Bt)/(sqrt(2*M*B0)+sum(sqrt(Bt)))
  return(c(q0,qt))
}

#-------------------------------------------------------------------------------
# Parameters
#-------------------------------------------------------------------------------

pt <- c(0,0.2,0.5,0.8)
sigma2_00 <- 1
sigma2_1t <- rep(1,length(pt)-1)
sigma2_0t <- rep(1,length(pt)-1)

rho_00 <- 0.1 # Change to 0.1, 0.5, 0.8

rho_0t <- rep(rho_00,length(pt)-1)
rho_1t <- rep(rho_00,length(pt)-1)
tauseq <- seq(-2,2,by=0.0001)

pos <- 4 # which TE parameter

R <- matrix(NA,nrow=4,ncol=6)

for(row in 1:4){
  
  #-------------------------------------------------------------------------------
  # Group size distribution
  #-------------------------------------------------------------------------------

  G <- data[row,1]
  nbar <- data[row,2]
  nvar <- data[row,3]
  
  #-------------------------------------------------------------------------------
  # Optimal group probabilities
  #-------------------------------------------------------------------------------
  
  qstar <- qopt(pt,sigma2_00,sigma2_0t,sigma2_1t,rho_00,rho_0t,rho_1t,nbar,nvar)
  q2 <- qopt(pt,sigma2_00,sigma2_0t,sigma2_1t,rho_00,rho_0t,rho_1t,nbar,0)
  
  p1 <- pt[pos]
  q1 <- qstar[pos]
  q0 <- qstar[1]
  
  q1_2 <- q2[pos]
  q0_2 <- q2[1]
  
  #-------------------------------------------------------------------------------
  # Variances with optimal q
  #-------------------------------------------------------------------------------
  
  V <- varfun(sigma2_0t[pos-1],sigma2_00,G,nbar,nvar,p1,q1,q0,rho_0t[pos-1],rho_00)
  V2 <- varfun(sigma2_0t[pos-1],sigma2_00,G,nbar,0,p1,q1_2,q0_2,rho_0t[pos-1],rho_00)
  
  #-------------------------------------------------------------------------------
  # Power and MDE
  #-------------------------------------------------------------------------------
  
  beta <- powerfun(V,tauseq,0.05)
  beta2 <- powerfun(V2,tauseq,0.05)
  
  MDE1 <- tauseq[min(which(beta<=0.8))-1]
  MDE2 <- tauseq[max(which(beta<=0.8))+1]
  MDE <- min(abs(MDE1),abs(MDE2))
  
  MDE1_2 <- tauseq[min(which(beta2<=0.8))-1]
  MDE2_2 <- tauseq[max(which(beta2<=0.8))+1]
  MDE_2 <- min(abs(MDE1_2),abs(MDE2_2))
  
  R[row,] <- c(sqrt(V),sqrt(V2),sqrt(V)/sqrt(V2),MDE,MDE_2,MDE/MDE_2)

}

round(R,4)

#write.csv(R,file=paste0("num_results_",rho_00*100,".csv"),row.names=FALSE)
