**********************************************
** Balance checks
**********************************************

*Open working database
use working_data.dta, clear
tab T tratado if periodo==202010


*first, prepare some variables

gen pr_value = (valuacion_3f>0 & valuacion_3f!=.)
gen lvalue = log(valuacion_3f)

tab categoria if periodo==201912
gen vivienda = 0 if categoria==2 & periodo==201912
replace vivienda = 1 if categoria==1 & periodo==201912

*number of bills paid in 2019
gen aux = pago_cuota_pre if periodo>=201901 & periodo<=201912
egen n_payments_2019=total(aux), by(id)
tab n_payments_2019 if periodo==201912


**********************************************
** Saturated regressions
**********************************************
*Saturated regression to jointly estimate all the parameters
*Standard errors clustered by blocks (num_cuadra)

*main result
reg pago_cuota_3oct20 treat1 treat2 treat3 control1 control2 control3 if periodo==202010, cluster(num_cuadra)
reg pago_cuota_oct20 treat1 treat2 treat3 control1 control2 control3 if periodo==202010, cluster(num_cuadra)

*ARBA indicator works, but it's hard to explain what it measures
reg arba treat1 treat2 treat3 control1 control2 control3 if periodo==201912, cluster(num_cuadra)


*******************
** Table
*******************

*regressions
*reg pr_value treat1 treat2 treat3 control1 control2 control3 if periodo==201912, cluster(num_cuadra)
reg lvalue treat1 treat2 treat3 control1 control2 control3 if periodo==201912, cluster(num_cuadra)
estimates store reg1
estadd scalar cons = _b[_cons]
reg metros_frente treat1 treat2 treat3 control1 control2 control3 if periodo==201912, cluster(num_cuadra)
estimates store reg2
estadd scalar cons = _b[_cons]
reg vivienda treat1 treat2 treat3 control1 control2 control3 if periodo==201912, cluster(num_cuadra)
estimates store reg3
estadd scalar cons = _b[_cons]
reg hombre_cuit treat1 treat2 treat3 control1 control2 control3 if periodo==201912, cluster(num_cuadra)
estimates store reg4
estadd scalar cons = _b[_cons]
reg edad_cuit treat1 treat2 treat3 control1 control2 control3 if periodo==201912, cluster(num_cuadra)
estimates store reg5
estadd scalar cons = _b[_cons]
*reg pago_cuota_pre treat1 treat2 treat3 control1 control2 control3 if periodo==201912, cluster(num_cuadra)
reg monto_pago_pre treat1 treat2 treat3 control1 control2 control3 if periodo==201912, cluster(num_cuadra)
estimates store reg6
estadd scalar cons = _b[_cons]
reg n_payments_2019 treat1 treat2 treat3 control1 control2 control3 if periodo==201912, cluster(num_cuadra)
estimates store reg7
estadd scalar cons = _b[_cons]
reg pago_digital treat1 treat2 treat3 control1 control2 control3 if periodo==201912, cluster(num_cuadra)
estimates store reg8
estadd scalar cons = _b[_cons]

local options_estout "coeflabel(treat1 "\hspace{0.1cm} Treated" treat2 "\hspace{0.1cm} Treated" treat3 "\hspace{0.1cm} Treated" control1 "\hspace{0.1cm} Untreated" control2 "\hspace{0.1cm} Untreated" control3 "\hspace{0.1cm} Untreated") refcat(treat1 "\multicolumn{9}{l}{\emph{\textbf{C. Blocks with 20\% treated:}}}" treat2 "\multicolumn{9}{l}{\emph{\textbf{B. Blocks with 50\% treated:}}}" treat3 "\multicolumn{9}{l}{\emph{\textbf{A. Blocks with 80\% treated:}}}", nolabel) order(treat3 control3 treat2 control2 treat1 control1) substitute(\_ _) se star(* 0.10 ** 0.05 *** 0.01) nonotes collabels(none) eqlabels(none) mlabels(none) mgroups(none) cells((b(star fmt(2))) (se(fmt(2)par))) stats(cons N N_clust, fmt(2 %9.0fc) labels("Mean Pure Control" "Observations" "Number of clusters")) replace noconstant msign($-$)"

esttab reg1 reg2 reg3 reg4 reg5 reg6 reg7 reg8 using "$Results\saturated_regressions_balance.tex", `options_estout' booktabs title(Balance test saturated regressions) prehead("\begin{table}[H]\centering" "\small" "\caption{@title}" "\label{balance_table}" "\begin{center}" "\begin{threeparttable}" "\begin{adjustbox}{width=\textwidth}" "\begin{tabularx}{\textwidth}{l Y Y Y Y Y Y Y Y}" "\toprule" "\multicolumn{1}{l}{}&" "\multicolumn{1}{c}{Property}&" "\multicolumn{1}{c}{Front}&" "\multicolumn{1}{c}{House}&" "\multicolumn{1}{c}{Tenant}&" "\multicolumn{1}{c}{Tenant}&" "\multicolumn{1}{c}{Bill}&" "\multicolumn{1}{c}{N Bills}&" "\multicolumn{1}{c}{Digital}\\" "\multicolumn{1}{l}{}&" "\multicolumn{1}{c}{Value}&" "\multicolumn{1}{c}{Metres}&" "\multicolumn{1}{c}{type}&" "\multicolumn{1}{c}{Male}&" "\multicolumn{1}{c}{Age}&" "\multicolumn{1}{c}{amount}&" "\multicolumn{1}{c}{paid 2019}&" "\multicolumn{1}{c}{payment}\\" "\cline{2-9}") posthead("\midrule") prefoot("\midrule") postfoot("\bottomrule" "\end{tabularx}" "\end{adjustbox}" "\begin{tablenotes}[flushleft]" "\footnotesize" "Notes: This table shows balance test regressions to formally test for differences in observable characteristics between the treatment and control groups. Each column corresponds to a separate regression (equation (\ref{eqn:saturated_balance}) in the text). The dependent variables in each column are: (1) the log of assessed property value; (2) the front metres of the property; (3) an indicator for the property being a house versus a house with a store; (4) whether the tenant is male; (5) a proxy for the tenant's age (first two digits of the ID); (6) the amount paid in the bill corresponding to December 2019 (including zeroes); (7) the number of bills paid in 2019 (the maximum is 12); (8) for those who paid, whether they did so digitally. The row \emph{Mean Pure Control} displays the constant of each regression, corresponding to the average of the dependent variable for accounts in blocks with no treated units (\(T_g=0\)). Standard errors clustered by blocks are reported in parentheses. * p$<$0.10, ** p$<$0.05, *** p$<$0.01" "\end{tablenotes}" \end{threeparttable} \end{center} \end{table}) 


