********************************************************************************
** Prepare dataset for power calculations based on June 2020 baseline data
** 22-Sep-2020
********************************************************************************

use "Base 1 Cuenta Corriente por Cuenta 2019.dta", clear

reshape wide pago_cuota, i(id) j(cuota)

*Get the account id 
merge 1:1 id2 using "Base total con datos imprenta.dta", keepusing(nro_cuenta id) keep(match) nogen

rename num_cuadra g
codebook g

bysort g: gen gsize = _N
egen tag = tag(g)
tab gsize if tag==1

egen pago_total = rowtotal(pago*)
tab pago_total
drop pago_cuota*

gen pago_todas = pago_total == 12
gen pago_alguna = pago_total>0
gen pago_seis = pago_total>=6

sum pago_*

order g tag
gsort g id2 -tag


** Create data_baseline.dta
preserve
*Restrict to block-streets with 8-50 properties (requested by municipality)
drop if gsize<8 | gsize>50

sum gsize if tag==1

gen gcat = 1 if gsize<=15
replace gcat = 2 if gsize>15 & gsize<=25
replace gcat = 3 if gsize>25
tab gcat if tag==1
tab gcat

hist gsize if tag==1, disc freq color(gs10%70) xlabels(8(2)50) graphregion(color(white)) bgcolor(white) xtitle(Accounts per block)
*graph export gsize.pdf, replace

*Save data used for randomization
save data_baseline.dta, replace
*export delimited using data_baseline.csv, replace
restore


** Create data_illustration.csv to use in R for Table 1 
drop if gsize<8

sum gsize if tag==1

hist gsize if tag==1, disc freq color(gs10%70) graphregion(color(white)) bgcolor(white) xtitle(Accounts per block)

rename pago_seis Y
rename g cluster
keep id2 gsize cluster Y
order id2 cluster Y
export delimited id2 cluster Y using "data_illustration.csv", replace

