** Prepare working data


**----------------- Undelivered Letters
import excel using "BOLETAS DIGITALES (3).xlsx", clear first
rename PARTIDA nro_cuenta
gen undelivered_letter = 1
keep nro_cuenta undelivered_letter
duplicates drop
tempfile undelivered
save `undelivered', replace

**----------------- Main Data (outcomes + covariates)

use "Base 1 Cuenta Corriente por Cuenta al 10Mar.dta", clear

unique id2
unique num_cuadra
gen periodo=string(anio)+"0"+string(cuota) if cuota<=9
replace periodo=string(anio)+string(cuota) if cuota>9
destring periodo, replace
bys id2: gen uno=_n

**----------------- Baseline data with T and C groups assignment
merge m:1 id using "randomization_final.dta"
drop _merge

**----------------- Data provided by municipality with location
merge m:1 id using "Base total con datos imprenta.dta"
tab T if _merge==3 & uno==1
tab id_id2 if T!=.
tab id_id2 if T==.
order id2 id nro_cuenta anio cuota periodo uno T tratado
tab a_dropear T if uno==1
drop if a_dropear==1

*flag accounts with undelivered letters 
*(1.4% of 68,808 accounts; 3.8% of 25,061 treated)
merge m:1 nro_cuenta using `undelivered', gen(merge_undelivered)
drop if merge_undelivered==2
tab merge_undelivered if uno==1
tab merge_undelivered if uno==1 & T!=.
tab merge_undelivered if uno==1 & tratado==1
replace undelivered_letter=0 if undelivered_letter==. & T!=.
table T if uno==1, c(freq mean undelivered_letter sum undelivered_letter) row
tab tratado if uno==1

*keep obsservation that are part of the experiment
drop if tratado==.

**********************************************
** Create dummy variables
**********************************************
sort id anio cuota
tab cuota if anio==2020

**groups for total effects
gen treat1=0 if T!=.
replace treat1=1 if tratado==1 & T==1
gen treat2=0 if T!=.
replace treat2=1 if tratado==1 & T==2
gen treat3=0 if T!=.
replace treat3=1 if tratado==1 & T==3

gen treat_123=0 if T==0
replace treat_123=1 if tratado==1

gen g_treat=0 if T==0
replace g_treat=1 if tratado==1 & T==1
replace g_treat=2 if tratado==1 & T==2
replace g_treat=3 if tratado==1 & T==3

**groups for spillover effects
gen control1=0 if T!=.
replace control1=1 if tratado==0 & T==1
gen control2=0 if T!=.
replace control2=1 if tratado==0 & T==2
gen control3=0 if T!=.
replace control3=1 if tratado==0 & T==3

gen control_123=0 if T==0
replace control_123=1 if tratado==0 & (T==1 | T==2 | T==3)

gen g_control=0 if T==0
replace g_control=1 if tratado==0 & T==1
replace g_control=2 if tratado==0 & T==2
replace g_control=3 if tratado==0 & T==3

*some cases with payment date but coded as unpaid
tab periodo if pago_cuota==0 & fpago_are!=.
tab caja_are if pago_cuota==0 & fpago_are!=., m
tab caja_are if pago_cuota==0 & fpago_are!=. & monto_pago==0, m

replace pago_cuota=1 if pago_cuota==0 & monto_pago==0 & fpago_are!=.
replace monto_pago=monto_debito if pago_cuota==1 & monto_pago==0 & fpago_are!=.

*recode accounts with negative values (credit) as paid=1
gen auxi=1 if pago_cuota==. & monto_debito<0 & (monto_pago==0 | monto_pago<0)
replace pago_cuota=1 if auxi==1
replace monto_pago=monto_debito if pago_cuota==1 & monto_pago==0 & fpago_are!=.
replace fpago_are=fvto if auxi==1 & fpago_are==.
drop auxi

*pagos anuales
replace pago_cuota=1 if pago_cuota==0 & monto_pago==0 & fpago_are!=. & pago_anual_cuenta_anio==1


*log and inverse hyperbolic sine
gen lmonto = log(monto_pago + 1)
gen ihs_monto = asinh(monto_pago)

*ejemplo de pago anual en agosto 2020, pero con unpaid status en el resto de los meses
*id=="6682005"  id=="6683752"

*Due date billing period October 2020: 09oct2020
tab fvto if periodo==202010
tab fvto if periodo==202009

tab localidad if periodo==202010 & fpago_are==mdy(10,1,2020), m
tab codigo_postal if periodo==202010 & fpago_are==mdy(10,1,2020), m
tab codigo_postal if periodo==202010, m

*Destring num_cuadra
tab num_cuadra if missing(real(num_cuadra))
replace num_cuadra="3232" if num_cuadra=="32B"
destring num_cuadra, replace
encode calle, gen(street)
drop calle


**********************************************
** Payments up to specific dates
**********************************************
*key: replace pago_cuota=0 if monthly fee is paid after the date

*Individual-level counterfactual
*Payments up to the day before the intervention began on 28-09-2020
gen pago_cuota_pre=.
replace pago_cuota_pre=pago_cuota if (fpago_are<=mdy(9,15,2020) | fpago_are==.)
replace pago_cuota_pre=0 if (fpago_are>mdy(9,15,2020) & fpago_are!=.)
replace pago_cuota_pre=. if periodo>202009
tab pago_cuota_pre if periodo==202009, m

gen monto_pago_pre=.
replace monto_pago_pre=monto_pago if (fpago_are<=mdy(9,15,2020) | fpago_are==.)
replace monto_pago_pre=0 if (fpago_are>mdy(9,15,2020) & fpago_are!=.)
replace monto_pago_pre=. if periodo>202009
gen ihs_monto_pre = asinh(monto_pago_pre)

*Payments up to 3 October 2020 (very short run)
gen pago_cuota_3oct20=.
replace pago_cuota_3oct20=pago_cuota if (fpago_are<=mdy(10,3,2020) | fpago_are==.)
replace pago_cuota_3oct20=0 if (fpago_are>mdy(10,3,2020) & fpago_are!=.)
replace pago_cuota_3oct20=. if periodo>202010
regress pago_cuota_3oct20 treat1 treat2 treat3 control1 control2 control3 if periodo==202010, cluster(num_cuadra)

*Payments up to the due date (October 9, 2020)
gen pago_cuota_9oct20=.
replace pago_cuota_9oct20=pago_cuota if (fpago_are<=mdy(10,9,2020) | fpago_are==.)
replace pago_cuota_9oct20=0 if (fpago_are>mdy(10,9,2020) & fpago_are!=.)
tab pago_cuota_9oct20 if periodo==202010, m
regress pago_cuota_9oct20 treat_123 if periodo==202010, cluster(num_cuadra)

*Payments up to 31 October 2020
gen pago_cuota_oct20=.
replace pago_cuota_oct20=pago_cuota if (fpago_are<=mdy(10,31,2020) | fpago_are==.)
replace pago_cuota_oct20=0 if (fpago_are>mdy(10,31,2020) & fpago_are!=.)
replace pago_cuota_oct20=. if periodo>202010
tab pago_cuota_oct20 if periodo==202010, m
regress pago_cuota_oct20 treat_123 if periodo==202010, cluster(num_cuadra)

*Payments up to 30 November 2020
gen pago_cuota_nov20=.
replace pago_cuota_nov20=pago_cuota if (fpago_are<=mdy(11,30,2020) | fpago_are==.)
replace pago_cuota_nov20=0 if (fpago_are>mdy(11,30,2020) & fpago_are!=.)
replace pago_cuota_nov20=. if periodo>202011
tab pago_cuota_nov20 if periodo==202010, m
regress pago_cuota_nov20 treat_123 if periodo==202010, cluster(num_cuadra)

*Payments up to 31 December 2020
gen pago_cuota_dec20=.
replace pago_cuota_dec20=pago_cuota if (fpago_are<=mdy(12,31,2020) | fpago_are==.)
replace pago_cuota_dec20=0 if (fpago_are>mdy(12,31,2020) & fpago_are!=.)
replace pago_cuota_dec20=. if periodo>202012
tab pago_cuota_dec20 if periodo==202010, m
regress pago_cuota_dec20 treat_123 if periodo==202010, cluster(num_cuadra)
reg pago_cuota_dec20 treat1 treat2 treat3 control1 control2 control3 if periodo==202010, cluster(num_cuadra)

*Payments up to 31 January 2021
gen pago_cuota_jan21=.
replace pago_cuota_jan21=pago_cuota if (fpago_are<=mdy(1,31,2021) | fpago_are==.)
replace pago_cuota_jan21=0 if (fpago_are>mdy(1,31,2021) & fpago_are!=.)
replace pago_cuota_jan21=. if periodo>202101
tab pago_cuota_jan21 if periodo==202010, m
regress pago_cuota_jan21 treat_123 if periodo==202010, cluster(num_cuadra)


drop _merge drop_postal drop_cuadra drop_cuota_10 drop_categoria drop_grandes_parcelas a_dropear

*save data
save working_data.dta, replace
