** Main analysis and Heterogeneity 
local bgopt "plotregion(icolor(white)) graphregion(fcolor(white) color(white)) bgcolor(white)"

*Open working database
use working_data.dta, clear
tab T tratado if periodo==202010

*generate sample indicator for regressions
reg pago_cuota_3oct20 treat1 treat2 treat3 control1 control2 control3 if periodo==202010, cluster(num_cuadra)
gen aux=1 if e(sample)==1
egen reg_sample = max(aux), by(id)


****************************
* VARIABLES TO SPLIT SAMPLE
****************************

*Accounts per block (cuadra)
bysort num_cuadra periodo: gen gsize = _N if periodo==202010
egen tag = tag(num_cuadra) if periodo==202010
tab gsize if tag==1
sum gsize if tag==1, d

**COMPLIANCE IN 2019

*Figure B.15
*individual-level compliance
gen aux2019=pago_cuota_pre if anio==2019
egen share_indiv_2019 = mean(aux2019), by(nro_cuenta)
egen N_indiv_2019 = total(aux2019), by(nro_cuenta)
drop aux2019

sum share_indiv_2019 if periodo==202010, d
tab N_indiv_2019 if periodo==202010
hist share_indiv_2019 if periodo==202010, frac color(gs10%70) xlabels(#8) ylab(, angle(0)) `bgopt' xtitle(Share payments 2019) xsize(8)
hist N_indiv_2019 if periodo==202010, frac discrete color(gs10%70) xlabels(0(1)12) ylab(, angle(0)) `bgopt' xtitle(Number of bills paid in 2019) xsize(8) text(.3 0 "35%", size(medlarge)) text(.4 12 "45%", size(medlarge)) subtitle("Share of" "accounts", placement(7) span) ytit("")
graph export "$Results\share_Nbills_indiv_2019.pdf", replace

*block-level compliance: share compliance in 2019
gen aux2019=pago_cuota_pre if anio==2019
egen share_block_2019 = mean(aux2019), by(num_cuadra)
drop aux2019
sum share_block_2019 if tag==1, d
hist share_block_2019 if tag==1, freq color(gs10%70) xlabels(0(.1)1) ylab(, angle(0)) `bgopt' xtitle(Share of bills paid in 2019 - by block) xsize(8) text(250 0.8 "Mean = 0.55" "p50 = 0.56" "N = 3,981", size(medlarge)) subtitle("N blocks", placement(7) span) ytit("")
graph export "$Results\share_compliance_2019.pdf", replace


*Figure B.16
**COMPLIANCE IN 2020 vs 2019 vs 2018 (mismo mes)

gen aux2018=pago_cuota_mismo_mes if anio==2018 & cuota<=9
egen share_block_2018_mismo_mes = mean(aux2018), by(num_cuadra)
gen aux2019=pago_cuota_mismo_mes if anio==2019 & cuota<=9
egen share_block_2019_mismo_mes = mean(aux2019), by(num_cuadra)
gen aux2020=pago_cuota_mismo_mes if anio==2020 & cuota<=9
egen share_block_2020_mismo_mes = mean(aux2020), by(num_cuadra)
drop aux2018 aux2019 aux2020
sum share_block_2018_mismo_mes if tag==1, d
sum share_block_2019_mismo_mes if tag==1, d
sum share_block_2020_mismo_mes if tag==1, d

twoway (hist share_block_2018_mismo_mes if tag==1, freq color(red%30) width(.03) start(0)) (hist share_block_2019_mismo_mes if tag==1, freq color(gs10%70) width(.03) start(0)), xlabels(0(.1)1) ylab(, angle(0)) `bgopt' xtitle(Share of bills paid - by block) legend(order(1 "2018" 2 "2019") ring(0) pos(1) col(1)) xsize(8) subtitle("N blocks", placement(7) span) ytit("")
graph export "$Results\share_compliance_2018_2019.pdf", replace

twoway (hist share_block_2020_mismo_mes if tag==1, freq color(green%30) width(.03) start(0)) (hist share_block_2019_mismo_mes if tag==1, freq color(gs10%70) width(.03) start(0)), xlabels(0(.1)1) ylab(, angle(0)) `bgopt' xtitle(Share of bills paid - by block) legend(order(1 "2020" 2 "2019") ring(0) pos(1) col(1)) xsize(8) subtitle("N blocks", placement(7) span) ytit("")
graph export "$Results\share_compliance_2018_2020.pdf", replace

*Figure B.17
*Is compliance decreasing more in more compliant blocks?
preserve
gen grupo = .
replace grupo = 1 if share_block_2019_mismo_mes>=0 & share_block_2019_mismo_mes<0.1
replace grupo = 2 if share_block_2019_mismo_mes>=0.1 & share_block_2019_mismo_mes<0.2
replace grupo = 3 if share_block_2019_mismo_mes>=0.2 & share_block_2019_mismo_mes<0.3
replace grupo = 4 if share_block_2019_mismo_mes>=0.3 & share_block_2019_mismo_mes<0.4
replace grupo = 5 if share_block_2019_mismo_mes>=0.4 & share_block_2019_mismo_mes<0.5
replace grupo = 6 if share_block_2019_mismo_mes>=0.5 & share_block_2019_mismo_mes<0.6
replace grupo = 7 if share_block_2019_mismo_mes>=0.6 & share_block_2019_mismo_mes<0.7
replace grupo = 8 if share_block_2019_mismo_mes>=0.7 & share_block_2019_mismo_mes<0.8
replace grupo = 9 if share_block_2019_mismo_mes>=0.8 & share_block_2019_mismo_mes<0.9
replace grupo = 10 if share_block_2019_mismo_mes>=0.9 & share_block_2019_mismo_mes<=1

collapse share_block_2018_mismo_mes share_block_2019_mismo_mes share_block_2020_mismo_mes if tag==1, by(grupo)
gen sh45 = _n/10
replace sh45 = 0 in 1

twoway (scatter share_block_2020_mismo_mes share_block_2019_mismo_mes, mcol(blue%60) lcol(blue) mlcol(blue)) (scatter share_block_2018_mismo_mes share_block_2019_mismo_mes, mcol(red%90) msy(t)) (line sh45 sh45, col(black)), `bgopt' xlabels(0(.1)1) ylab(0(.1)1, angle(0) nogrid) xsize(5) legend(off) xtit(Share of bills paid in {bf:2019}) ytit(Share of bills paid in {bf:2018 or 2020}) text(.77 .95 "2018", color(red) size(large)) text(.6 .95 "2020", color(blue) size(large)) text(.99 .9 "45{c 176} line")
graph export "$Results\share_compliance_transition.pdf", replace
restore



**************************************
* BELOW AND ABOVE THE MEDIAN
* OF -----------CUADRA-------------
**************************************
*dates: 3oct20 9oct20 oct20

bys num_cuadra: gen cuad=1 if _n==1

************************
***Var of heterogeneity
************************
local range share_block_2019

capture drop med1 med2 

*Mediana
_pctile `range' if cuad!=., nq(2)
ret list
loc median=r(r1)

gen med1=`range'<= `median' 
gen med2=`range'> `median' 

tab cuad if med1
tab cuad if med2

*Grafico de all, above/below median
*Version grafico de la tabla, for presentations
capture program drop mygraph4
program define mygraph4

local bgopt "plotregion(icolor(white)) graphregion(fcolor(white) color(white)) bgcolor(white)"

reg pago_cuota_`1' treat1 treat2 treat3 control1 control2 control3  if periodo==`2' & reg_sample==1, cluster(num_cuadra)
local i=1
matrix A = r(table)
matrix T1_`i' = ( (A[1,1])' , (A[5,1])' , (A[6,1])' ) * 100
matrix T2_`i' = ( (A[1,2])' , (A[5,2])' , (A[6,2])' ) * 100
matrix T3_`i' = ( (A[1,3])' , (A[5,3])' , (A[6,3])' ) * 100
matrix C1_`i' = ( (A[1,4])' , (A[5,4])' , (A[6,4])' ) * 100
matrix C2_`i' = ( (A[1,5])' , (A[5,5])' , (A[6,5])' ) * 100
matrix C3_`i' = ( (A[1,6])' , (A[5,6])' , (A[6,6])' ) * 100

*below the median
reg pago_cuota_`1' treat1 treat2 treat3 control1 control2 control3  if periodo==`2' & reg_sample==1 & med1==1, cluster(num_cuadra)
local i=2
matrix A = r(table)
matrix T1_`i' = ( (A[1,1])' , (A[5,1])' , (A[6,1])' ) * 100
matrix T2_`i' = ( (A[1,2])' , (A[5,2])' , (A[6,2])' ) * 100
matrix T3_`i' = ( (A[1,3])' , (A[5,3])' , (A[6,3])' ) * 100
matrix C1_`i' = ( (A[1,4])' , (A[5,4])' , (A[6,4])' ) * 100
matrix C2_`i' = ( (A[1,5])' , (A[5,5])' , (A[6,5])' ) * 100
matrix C3_`i' = ( (A[1,6])' , (A[5,6])' , (A[6,6])' ) * 100

*above the median
reg pago_cuota_`1' treat1 treat2 treat3 control1 control2 control3  if periodo==`2' & reg_sample==1 & med2==1, cluster(num_cuadra)
local i=3
matrix A = r(table)
matrix T1_`i' = ( (A[1,1])' , (A[5,1])' , (A[6,1])' ) * 100
matrix T2_`i' = ( (A[1,2])' , (A[5,2])' , (A[6,2])' ) * 100
matrix T3_`i' = ( (A[1,3])' , (A[5,3])' , (A[6,3])' ) * 100
matrix C1_`i' = ( (A[1,4])' , (A[5,4])' , (A[6,4])' ) * 100
matrix C2_`i' = ( (A[1,5])' , (A[5,5])' , (A[6,5])' ) * 100
matrix C3_`i' = ( (A[1,6])' , (A[5,6])' , (A[6,6])' ) * 100

matrix R =  C3_1 \ C3_2 \ C3_3 
matrix S =  T3_1 \ T3_2 \ T3_3 
matrix T =  C2_1 \ C2_2 \ C2_3 
matrix U =  T2_1 \ T2_2 \ T2_3 
matrix V =  C1_1 \ C1_2 \ C1_3 
matrix W =  T1_1 \ T1_2 \ T1_3 
capture drop R1-W3 xvar xvar2
svmat R 
svmat S
svmat T
svmat U
svmat V
svmat W
gen xvar = _n if _n<=3
gen xvar2=xvar+0.1

*Split by median of share of bills paid by block in 2019

twoway (rspike S2 S3 xvar2, sort color(navy%40) msize(*.7)) (scatter S1 xvar2, msy(O) mcol(navy%40) lcol(navy) mlcol(navy)) (rspike R2 R3 xvar, sort color(maroon%40) msize(*.7)) (scatter R1 xvar, msy(T) mcol(maroon%40) lcol(maroon) mlcol(maroon)), `bgopt' xlabel(0.75 " " 1 "All" 2 "Below median" 3 "Above median" 3.25 " ", labsize(large)) ylab(-4(1)8, angle(0) nogrid) ytit("Treatment effect (p.p.)") title("Blocks w/ 80% treated",suffix) xtit("") yline(0, lcol(black) lpat(dot)) legend(order(2 "Treated" 4 "Untreated") region(style(none)) ring(0) col(1) pos(11) size(medium)) name(c3, replace) xsize(6)
graph export "$Results\het-`1'-g3.pdf", replace


twoway (rspike U2 U3 xvar2, sort color(navy%40) msize(*.7)) (scatter U1 xvar2, msy(O) mcol(navy%40) lcol(navy) mlcol(navy)) (rspike T2 T3 xvar, sort color(maroon%40) msize(*.7)) (scatter T1 xvar, msy(T) mcol(maroon%40) lcol(maroon) mlcol(maroon)), `bgopt' xlabel(0.75 " " 1 "All" 2 "Below median" 3 "Above median" 3.25 " ", labsize(large)) ylab(-4(1)8, angle(0) nogrid) ytit("Treatment effect (p.p.)") title("Blocks w/ 50% treated",suffix) xtit("") yline(0, lcol(black) lpat(dot)) legend(order(2 "Treated" 4 "Untreated") region(style(none)) ring(0) col(1) pos(11) size(medium)) name(c2, replace) xsize(6)
graph export "$Results\het-`1'-g2.pdf", replace


twoway (rspike W2 W3 xvar2, sort color(navy%40) msize(*.7)) (scatter W1 xvar2, msy(O) mcol(navy%40) lcol(navy) mlcol(navy)) (rspike V2 V3 xvar, sort color(maroon%40) msize(*.7)) (scatter V1 xvar, msy(T) mcol(maroon%40) lcol(maroon) mlcol(maroon)), `bgopt' xlabel(0.75 " " 1 "All" 2 "Below median" 3 "Above median" 3.25 " ", labsize(large)) ylab(-4(1)8, angle(0) nogrid) ytit("Treatment effect (p.p.)") title("Blocks w/ 20% treated",suffix) xtit("") yline(0, lcol(black) lpat(dot)) legend(order(2 "Treated" 4 "Untreated") region(style(none)) ring(0) col(1) pos(11) size(medium)) name(c1, replace) xsize(6)
graph export "$Results\het-`1'-g1.pdf", replace

end


mygraph4 pre 202009

mygraph4 3oct20 202010

mygraph4 oct20 202010




*******************
** Tables
*******************

replace pago_cuota_pre = pago_cuota_pre*100
replace pago_cuota_3oct20 = pago_cuota_3oct20*100
replace pago_cuota_9oct20 = pago_cuota_9oct20*100
replace pago_cuota_oct20 = pago_cuota_oct20*100

*******************
** Table 2 - version REStat 45 pages
*******************
*heterogeneous effects
*Split by median of share of bills paid by block in 2019

*Placebo bill
reg pago_cuota_pre treat1 treat2 treat3 control1 control2 control3 if periodo==202009 & reg_sample==1, cluster(num_cuadra)
estimates store reg1
estadd scalar cons = _b[_cons]

reg pago_cuota_pre treat1 treat2 treat3 control1 control2 control3 if periodo==202009 & reg_sample==1 & med1==1, cluster(num_cuadra)
estimates store reg1below
estadd scalar cons = _b[_cons]

reg pago_cuota_pre treat1 treat2 treat3 control1 control2 control3 if periodo==202009 & reg_sample==1 & med2==1, cluster(num_cuadra)
estimates store reg1above
estadd scalar cons = _b[_cons]

*Early effects
reg pago_cuota_3oct20 treat1 treat2 treat3 control1 control2 control3 if periodo==202010 & reg_sample==1, cluster(num_cuadra)
estimates store reg2
estadd scalar cons = _b[_cons]

reg pago_cuota_3oct20 treat1 treat2 treat3 control1 control2 control3 if periodo==202010 & reg_sample==1 & med1==1, cluster(num_cuadra)
estimates store reg2below
estadd scalar cons = _b[_cons]

reg pago_cuota_3oct20 treat1 treat2 treat3 control1 control2 control3 if periodo==202010 & reg_sample==1 & med2==1, cluster(num_cuadra)
estimates store reg2above
estadd scalar cons = _b[_cons]

*End-of-month effects
reg pago_cuota_oct20 treat1 treat2 treat3 control1 control2 control3 if periodo==202010 & reg_sample==1, cluster(num_cuadra)
estimates store reg4
estadd scalar cons = _b[_cons]

reg pago_cuota_oct20 treat1 treat2 treat3 control1 control2 control3 if periodo==202010 & reg_sample==1 & med1==1, cluster(num_cuadra)
estimates store reg4below
estadd scalar cons = _b[_cons]

reg pago_cuota_oct20 treat1 treat2 treat3 control1 control2 control3 if periodo==202010 & reg_sample==1 & med2==1, cluster(num_cuadra)
estimates store reg4above
estadd scalar cons = _b[_cons]


local options_estout "coeflabel(treat1 "\hspace{0.1cm} Treated" treat2 "\hspace{0.1cm} Treated" treat3 "\hspace{0.1cm} Treated" control1 "\hspace{0.1cm} Untreated" control2 "\hspace{0.1cm} Untreated" control3 "\hspace{0.1cm} Untreated") refcat(treat1 "\emph{\textbf{C. Blocks with 20\% treated}}" treat2 "\emph{\textbf{B. Blocks with 50\% treated}}" treat3 "\emph{\textbf{A. Blocks with 80\% treated}}", nolabel) order(treat3 control3 treat2 control2 treat1 control1) substitute(\_ _) se star(* 0.10 ** 0.05 *** 0.01) nonotes collabels(none) eqlabels(none) mlabels(none) mgroups(none) cells((b(star fmt(2))) (se(fmt(2)par))) stats(cons N N_clust, fmt(2 %9.0fc) labels("Payment rate of pure control" "Observations" "Number of clusters (blocks)")) replace noconstant"

esttab reg2 reg2below reg2above reg4 reg4below reg4above using "$Results\saturated_regressions_REStat.tex", `options_estout' booktabs title(Direct and spillover effects on property tax payments) prehead("\begin{table}[H]\centering" "\small" "\caption{@title}" "\label{heterogeneous}" "\begin{center}" "\begin{threeparttable}" "\begin{tabularx}{\textwidth}{l Y Y Y Y Y Y}" "\toprule" " &" "\multicolumn{3}{c}{\textbf{Early Payments}}&" "\multicolumn{3}{c}{\textbf{On-time \& Late Payments}}\\" "\cline{2-4}" "\cline{5-7}" " &" "\multicolumn{1}{c}{}&" "\multicolumn{1}{c}{Below}&" "\multicolumn{1}{c}{Above}&" "\multicolumn{1}{c}{}&" "\multicolumn{1}{c}{Below}&" "\multicolumn{1}{c}{Above}\\" " &" "\multicolumn{1}{c}{All}&" "\multicolumn{1}{c}{Median}&" "\multicolumn{1}{c}{Median}&" "\multicolumn{1}{c}{All}&" "\multicolumn{1}{c}{Median}&" "\multicolumn{1}{c}{Median}\\") posthead("\midrule") prefoot("\midrule") postfoot("\bottomrule" "\end{tabularx}" "\begin{tablenotes}[flushleft]" "\footnotesize" "Notes: This table shows the results from saturated OLS regressions. The dependent variable in columns (1)-(3) is an indicator for paying the October 2020 bill by October 3rd (early payments); while in columns (4)-(6) we use an indicator for paying the October 2020 bill by October 31st (includes early, on time, and overdue payments). Columns (2) and (3) break the main result from column (1) into blocks below and above median compliance in 2019. We define compliance as the share of bills paid by block in 2019 with median value of 0.56 (see Figure \ref{figure:descriptives_heterogeneity}). Each column corresponds to a separate regression. The omitted category corresponds to blocks where no accounts were treated (pure control). Panel A shows the results for blocks where 80\% were treated, panel B for blocks with 50\% treated, and panel C for blocks with 20\% treated. The letters were delivered between September 28th and October 7th. The due date for the October 2020 bill was October 9th. The row \emph{Payment rate of pure control} displays the constant of each regression, corresponding to the average payment rate in blocks with no treated units. Standard errors clustered by blocks are reported in parentheses. * p$<$0.10, ** p$<$0.05, *** p$<$0.01" "\end{tablenotes}" \end{threeparttable} \end{center} \end{table}) 



*******************
** Table A4 - placebo REStat
*******************

local options_estout "coeflabel(treat1 "\hspace{0.1cm} Treated" treat2 "\hspace{0.1cm} Treated" treat3 "\hspace{0.1cm} Treated" control1 "\hspace{0.1cm} Untreated" control2 "\hspace{0.1cm} Untreated" control3 "\hspace{0.1cm} Untreated") refcat(treat1 "\emph{\textbf{C. Blocks with 20\% treated}}" treat2 "\emph{\textbf{B. Blocks with 50\% treated}}" treat3 "\emph{\textbf{A. Blocks with 80\% treated}}", nolabel) order(treat3 control3 treat2 control2 treat1 control1) substitute(\_ _) se star(* 0.10 ** 0.05 *** 0.01) nonotes collabels(none) eqlabels(none) mlabels(none) mgroups(none) cells((b(star fmt(2))) (se(fmt(2)par))) stats(cons N N_clust, fmt(2 %9.0fc) labels("Payment rate of pure control" "Observations" "Number of clusters (blocks)")) replace noconstant"

esttab reg1 reg1below reg1above using "$Results\saturated_regressions_REStat_placebo.tex", `options_estout' booktabs title(Placebo. Direct and spillover effects for the pre-intervention September 2020 bill) prehead("\begin{table}[H]\centering" "\small" "\caption{@title}" "\label{heterogeneous_placebo}" "\begin{center}" "\begin{threeparttable}" "\begin{tabularx}{\textwidth}{l Y Y Y}" "\toprule" "\multicolumn{1}{l}{\textbf{Dependent variable:}}&" "\multicolumn{3}{c}{\textbf{Placebo bill (September 2020)}}\\" "\cline{2-4}" "\multicolumn{1}{l}{Pr(pay the bill)}&" "\multicolumn{1}{c}{All}&" "\multicolumn{1}{c}{Below Median}&" "\multicolumn{1}{c}{Above Median}\\") posthead("\midrule") prefoot("\midrule") postfoot("\bottomrule" "\end{tabularx}" "\begin{tablenotes}[flushleft]" "\footnotesize" "Notes: This table shows the results from saturated OLS regressions using as dependent variable an indicator for paying the September 2020 bill by September 15th (pre-intervention). Each column corresponds to a separate regression. The omitted category corresponds to blocks where no accounts were treated (pure control). Panel A shows the results for blocks where 80\% were treated, panel B for blocks with 50\% treated, and panel C for blocks with 20\% treated. Columns (2) and (3) split the sample from column (1) into blocks below and above median compliance in 2019, respectively. We define compliance as the share of bills paid by block in 2019 with median value of 0.56 (see Figure \ref{figure:descriptives_heterogeneity}). The estimates reported in column (1) correspond exactly to the numbers shown in Figure (\ref{figure:payments_DD_sep20}). The row \emph{Payment rate of pure control} displays the constant of each regression, corresponding to the average payment rate in blocks with no treated units. Standard errors clustered by blocks are reported in parentheses. * p$<$0.10, ** p$<$0.05, *** p$<$0.01" "\end{tablenotes}" \end{threeparttable} \end{center} \end{table}) 


**************************************************
** Figures with CI - ALL & BELOW AND ABOVE THE MEDIAN
**************************************************

**********************************************
** Saturated regressions - October 2020
**********************************************
*Saturated regression to jointly estimate all the parameters
*Standard errors clustered by blocks (num_cuadra)

**Rectangularize dataset 
*(to obtain a balanced daily panel)
preserve
keep if periodo==202010 & reg_sample==1
keep id fpago_are pago_cuota treat1 treat2 treat3 control1 control2 control3 num_cuadra med1 med2
fillin id fpago_are

*payment dummy (=1 after people paid the October 2020 bill)
sort id fpago_are
bys id: gen paid_bill = sum( pago_cuota )

*expand num_cuadra
sort id num_cuadra
by id : replace num_cuadra = num_cuadra[1]
sort id fpago_are

*expand T/C status
foreach var of varlist treat1-control3 {
  egen d`var'=max(`var'), by(id)
}

*expand below/above p50 status
egen dmed1=max(med1), by(id)
egen dmed2=max(med2), by(id)

*keep relevant subperiod
*keep if ( fpago_are>=mdy(6,5,2020) & fpago_are<=mdy(12,31,2020) )
keep if ( fpago_are>=mdy(9,25,2020) & fpago_are<=mdy(10,31,2020) )

*unit fixed effect
gen aux = _n if fpago_are==mdy(9,25,2020)
egen idi = max(aux), by(id)
drop aux

*date relative to start of intervention
gen t=fpago_are-mdy(9,28,2020)
xi i.t, pref(_T)

tab fpago_are, gen(_T)

*Saturated regression with all groups

foreach g of varlist dtreat1 dtreat2 dtreat3 dcontrol1 dcontrol2 dcontrol3 {
foreach var of varlist _T1-_T37 {
  gen `g'`var' = `var'*`g'
}
}

**************************************************
** ALL TOGETHER
**************************************************
set matsize 2000
reg paid_bill dtreat1_T1-dcontrol3_T37 _T1-_T37, cluster(num_cuadra) nocons

matrix A = r(table)
*treated
matrix T1 = ( (A[1,1..37])' , (A[5,1..37])' , (A[6,1..37])' ) * 100
matrix T2 = ( (A[1,38..74])' , (A[5,38..74])' , (A[6,38..74])' ) * 100
matrix T3 = ( (A[1,75..111])' , (A[5,75..111])' , (A[6,75..111])' ) * 100
*untreated
matrix C1 = ( (A[1,112..148])' , (A[5,112..148])' , (A[6,112..148])' ) * 100
matrix C2 = ( (A[1,149..185])' , (A[5,149..185])' , (A[6,149..185])' ) * 100
matrix C3 = ( (A[1,186..222])' , (A[5,186..222])' , (A[6,186..222])' ) * 100
matrix R = T1,T2,T3,C1,C2,C3
svmat R
gen xvar = _n+22182 if _n<=37
format xvar %td

**treated
twoway (rspike R2 R3 xvar, sort color(navy%40) msize(*.5)) (connected R1 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) title("{bf:Blocks with 20% treated}", suffix) name(g1, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-treated1.pdf", replace 

twoway (rspike R5 R6 xvar, sort color(navy%40) msize(*.5)) (connected R4 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) title("{bf:Blocks with 50% treated}", suffix) name(g2, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-treated2.pdf", replace 

twoway (rspike R8 R9 xvar, sort color(navy%40) msize(*.5)) (connected R7 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) title("{bf:Blocks with 80% treated}", suffix) name(g3, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-treated3.pdf", replace 

*no title (for REStat version)
twoway (rspike R8 R9 xvar, sort color(black%40) msize(*.5)) (connected R7 xvar, msy(o) mcol(black) lcol(black) mlcol(black)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(black) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) name(g3, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-treated3-notitle.pdf", replace 


**untreated
twoway (rspike R11 R12 xvar, sort color(navy%40) msize(*.5)) (connected R10 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) title("{bf:Blocks with 20% treated}", suffix) name(g1, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-untreated1.pdf", replace 

twoway (rspike R14 R15 xvar, sort color(navy%40) msize(*.5)) (connected R13 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) title("{bf:Blocks with 50% treated}", suffix) name(g2, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-untreated2.pdf", replace 

twoway (rspike R17 R18 xvar, sort color(navy%40) msize(*.5)) (connected R16 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) title("{bf:Blocks with 80% treated}", suffix) name(g3, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-untreated3.pdf", replace

*no title (for REStat version)
twoway (rspike R17 R18 xvar, sort color(black%40) msize(*.5)) (connected R16 xvar, msy(o) mcol(black) lcol(black) mlcol(black)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(black) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) name(g3, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-untreated3-notitle.pdf", replace


**************************************************
** BELOW THE MEDIAN
**************************************************
drop R1 - xvar
reg paid_bill dtreat1_T1-dcontrol3_T37 _T1-_T37 if dmed1==1, cluster(num_cuadra) nocons

matrix A = r(table)
*treated
matrix T1 = ( (A[1,1..37])' , (A[5,1..37])' , (A[6,1..37])' ) * 100
matrix T2 = ( (A[1,38..74])' , (A[5,38..74])' , (A[6,38..74])' ) * 100
matrix T3 = ( (A[1,75..111])' , (A[5,75..111])' , (A[6,75..111])' ) * 100
*untreated
matrix C1 = ( (A[1,112..148])' , (A[5,112..148])' , (A[6,112..148])' ) * 100
matrix C2 = ( (A[1,149..185])' , (A[5,149..185])' , (A[6,149..185])' ) * 100
matrix C3 = ( (A[1,186..222])' , (A[5,186..222])' , (A[6,186..222])' ) * 100
matrix R = T1,T2,T3,C1,C2,C3
svmat R
gen xvar = _n+22182 if _n<=37
format xvar %td


**treated
twoway (rspike R2 R3 xvar, sort color(navy%40) msize(*.5)) (connected R1 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) title("{bf:BELOW MEDIAN}" "{bf:COMPLIANCE}", suffix color(red*.5)) name(g1, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-treated1-belowp50.pdf", replace 

twoway (rspike R5 R6 xvar, sort color(navy%40) msize(*.5)) (connected R4 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) title("{bf:BELOW MEDIAN}" "{bf:COMPLIANCE}", suffix color(red*.5)) name(g2, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-treated2-belowp50.pdf", replace 

twoway (rspike R8 R9 xvar, sort color(navy%40) msize(*.5)) (connected R7 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) title("{bf:BELOW MEDIAN}" "{bf:COMPLIANCE}", suffix color(red*.5)) name(g3, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-treated3-belowp50.pdf", replace 

*no title (for REStat version)
twoway (rspike R8 R9 xvar, sort color(black%40) msize(*.5)) (connected R7 xvar, msy(o) mcol(black) lcol(black) mlcol(black)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(black) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) name(g3, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-treated3-belowp50-notitle.pdf", replace 


**untreated
twoway (rspike R11 R12 xvar, sort color(navy%40) msize(*.5)) (connected R10 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) title("{bf:BELOW MEDIAN}" "{bf:COMPLIANCE}", suffix color(red*.5)) name(g1, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-untreated1-belowp50.pdf", replace 

twoway (rspike R14 R15 xvar, sort color(navy%40) msize(*.5)) (connected R13 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) title("{bf:BELOW MEDIAN}" "{bf:COMPLIANCE}", suffix color(red*.5)) name(g2, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-untreated2-belowp50.pdf", replace 

twoway (rspike R17 R18 xvar, sort color(navy%40) msize(*.5)) (connected R16 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) title("{bf:BELOW MEDIAN}" "{bf:COMPLIANCE}", suffix color(red*.5)) name(g3, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-untreated3-belowp50.pdf", replace

*no title (for REStat version)
twoway (rspike R17 R18 xvar, sort color(black%40) msize(*.5)) (connected R16 xvar, msy(o) mcol(black) lcol(black) mlcol(black)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(black) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) name(g3, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-untreated3-belowp50-notitle.pdf", replace


**************************************************
** ABOVE THE MEDIAN
**************************************************
drop R1 - xvar
reg paid_bill dtreat1_T1-dcontrol3_T37 _T1-_T37 if dmed2==1, cluster(num_cuadra) nocons

matrix A = r(table)
*treated
matrix T1 = ( (A[1,1..37])' , (A[5,1..37])' , (A[6,1..37])' ) * 100
matrix T2 = ( (A[1,38..74])' , (A[5,38..74])' , (A[6,38..74])' ) * 100
matrix T3 = ( (A[1,75..111])' , (A[5,75..111])' , (A[6,75..111])' ) * 100
*untreated
matrix C1 = ( (A[1,112..148])' , (A[5,112..148])' , (A[6,112..148])' ) * 100
matrix C2 = ( (A[1,149..185])' , (A[5,149..185])' , (A[6,149..185])' ) * 100
matrix C3 = ( (A[1,186..222])' , (A[5,186..222])' , (A[6,186..222])' ) * 100
matrix R = T1,T2,T3,C1,C2,C3
svmat R
gen xvar = _n+22182 if _n<=37
format xvar %td


**treated
twoway (rspike R2 R3 xvar, sort color(navy%40) msize(*.5)) (connected R1 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) title("{bf:ABOVE MEDIAN}" "{bf:COMPLIANCE}", suffix color(green)) name(g1, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-treated1-abovep50.pdf", replace 

twoway (rspike R5 R6 xvar, sort color(navy%40) msize(*.5)) (connected R4 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) title("{bf:ABOVE MEDIAN}" "{bf:COMPLIANCE}", suffix color(green)) name(g2, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-treated2-abovep50.pdf", replace 

twoway (rspike R8 R9 xvar, sort color(navy%40) msize(*.5)) (connected R7 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) title("{bf:ABOVE MEDIAN}" "{bf:COMPLIANCE}", suffix color(green)) name(g3, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-treated3-abovep50.pdf", replace 

*no title (for REStat version)
twoway (rspike R8 R9 xvar, sort color(black%40) msize(*.5)) (connected R7 xvar, msy(o) mcol(black) lcol(black) mlcol(black)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(black) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) name(g3, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-treated3-abovep50-notitle.pdf", replace 


**untreated
twoway (rspike R11 R12 xvar, sort color(navy%40) msize(*.5)) (connected R10 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) title("{bf:ABOVE MEDIAN}" "{bf:COMPLIANCE}", suffix color(green)) name(g1, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-untreated1-abovep50.pdf", replace 

twoway (rspike R14 R15 xvar, sort color(navy%40) msize(*.5)) (connected R13 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) title("{bf:ABOVE MEDIAN}" "{bf:COMPLIANCE}", suffix color(green)) name(g2, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-untreated2-abovep50.pdf", replace 

twoway (rspike R17 R18 xvar, sort color(navy%40) msize(*.5)) (connected R16 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) title("{bf:ABOVE MEDIAN}" "{bf:COMPLIANCE}", suffix color(green)) name(g3, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-untreated3-abovep50.pdf", replace

*no title (for REStat version)
twoway (rspike R17 R18 xvar, sort color(black%40) msize(*.5)) (connected R16 xvar, msy(o) mcol(black) lcol(black) mlcol(black)), `bgopt' xlabel(22183(7)22219) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(black) lpat(dash)) legend(off) xline(22186 22197, lpat(dot) lcol(black)) name(g3, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(medsmall) color(gray)) text(6.5 22193.5 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\payment-rate-diff-untreated3-abovep50-notitle.pdf", replace

restore


