** Graphical analysis
local bgopt "plotregion(icolor(white)) graphregion(fcolor(white) color(white)) bgcolor(white)"

*Open working database
use working_data.dta, clear
tab T tratado if periodo==202010


**********************************************
** Cuota 10 (October 2020)
** 1. Distribution of payment date by T vs C
** 2. Cumulative payment rate by calendar date
**********************************************

**Distribution of payment date by T vs C (for Cuota 10)
dis mdy(10,9,2020)
twoway (histogram fpago_are if periodo==202010 & fpago_are>mdy(9,15,2020) & fpago_are<=mdy(12,31,2020) & treat_123==1, color(navy%30) discrete frac) (histogram fpago_are if periodo==202010 & fpago_are>mdy(9,15,2020) & fpago_are<=mdy(12,31,2020) & treat_123==0, color(maroon%30) discrete frac), xline(22197.5, lpat(dash) lcol(gray)) `bgopt' legend(order(1 "Treated" 2 "Pure Control") ring(0) pos(1) row(2) region(style(none))) xtit("") ylab(,angle(0) nogrid) xlab(#7, labsize(small)) text(.14 22205 "Due date of" "October bill", size(small) color(gray))
graph export "$Results\payments-density1.pdf", replace 

twoway (histogram fpago_are if periodo==202010 & fpago_are>mdy(9,15,2020) & fpago_are<=mdy(12,31,2020) & control_123==1, color(navy%30) discrete frac) (histogram fpago_are if periodo==202010 & fpago_are>mdy(9,15,2020) & fpago_are<=mdy(12,31,2020) & control_123==0, color(maroon%30) discrete frac), xline(22197.5, lpat(dash) lcol(gray)) `bgopt' legend(order(1 "Untreated" 2 "Pure Control") ring(0) pos(1) row(2) region(style(none))) xtit("") ylab(,angle(0) nogrid) xlab(#7, labsize(small)) text(.14 22205 "Due date of" "October bill", size(small) color(gray))
graph export "$Results\payments-density2.pdf", replace 


**Cumulative payment rate (%) and difference between T=0,1,2,3

***Break untreated units into subgroups; pool treated units

preserve
replace g_control=4 if treat_123==1

*denominator
sum pago_cuota_oct20 if periodo==202010 & g_control==0
loc Nc=r(N)
sum pago_cuota_oct20 if periodo==202010 & g_control==1
loc Nc1=r(N)
sum pago_cuota_oct20 if periodo==202010 & g_control==2
loc Nc2=r(N)
sum pago_cuota_oct20 if periodo==202010 & g_control==3
loc Nc3=r(N)
sum pago_cuota_oct20 if periodo==202010 & g_control==4
loc Nt=r(N)

collapse (sum) Npayers=pago_cuota_oct20 if periodo==202010 & fpago_are<=mdy(10,31,2020) & fpago_are!=. & g_control!=., by(fpago_are g_control)
fillin g_control fpago_are
sort g_control fpago_are
bysort g_control : gen cum = sum(Npayers)
drop if fpago_are<=mdy(9,15,2020)
gen pay_rate = cum/`Nt'*100 if g_control==4
replace pay_rate = cum/`Nc'*100 if g_control==0
replace pay_rate = cum/`Nc1'*100 if g_control==1
replace pay_rate = cum/`Nc2'*100 if g_control==2
replace pay_rate = cum/`Nc3'*100 if g_control==3

*levels T vs pure C
twoway (line pay_rate fpago_are if g_control==4, color(navy%70)) (line pay_rate fpago_are if g_control==0, color(maroon%60) lpat(dash)), xline(22186 22197, lpat(dot) lcol(black)) `bgopt' legend(off) xtit("Calendar date") ylab(,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(22183(7)22219, labsize(small)) text(40 22186 "Intervention" "begins", size(small) color(gray)) text(40 22197 "Due date of" "October 2020" "billing period", size(small) color(gray)) ytit(Cumulative payment rate (%)) text(40 22212 "Treated (pooled)", color(navy%90)) text(30 22212 "Pure Control", color(maroon%90)) aspect(0.5) 
graph export "$Results\payment-rate-Oct2020-levels-treated.pdf", replace 

*levels C3 vs pure C
twoway (line pay_rate fpago_are if g_control==3, color(navy%70)) (line pay_rate fpago_are if g_control==0, color(maroon%60) lpat(dash)), xline(22186 22197, lpat(dot) lcol(black)) `bgopt' legend(off) xtit("Calendar date") ylab(,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(22183(7)22219, labsize(small)) text(40 22186 "Intervention" "begins", size(small) color(gray)) text(40 22197 "Due date of" "October 2020" "billing period", size(small) color(gray)) ytit(Cumulative payment rate (%)) text(37 22212 "Untreated (T=3)", color(navy%90)) text(30 22212 "Pure Control", color(maroon%90)) aspect(0.5) 
graph export "$Results\payment-rate-Oct2020-levels-untreated3.pdf", replace 

*levels C2 vs pure C
twoway (line pay_rate fpago_are if g_control==2, color(navy%70)) (line pay_rate fpago_are if g_control==0, color(maroon%60) lpat(dash)), xline(22186 22197, lpat(dot) lcol(black)) `bgopt' legend(off) xtit("Calendar date") ylab(,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(22183(7)22219, labsize(small)) text(40 22186 "Intervention" "begins", size(small) color(gray)) text(40 22197 "Due date of" "October 2020" "billing period", size(small) color(gray)) ytit(Cumulative payment rate (%)) text(36.5 22212 "Untreated (T=2)", color(navy%90)) text(30 22212 "Pure Control", color(maroon%90)) aspect(0.5) 
graph export "$Results\payment-rate-Oct2020-levels-untreated2.pdf", replace 

*levels C1 vs pure C
twoway (line pay_rate fpago_are if g_control==1, color(navy%70)) (line pay_rate fpago_are if g_control==0, color(maroon%60) lpat(dash)), xline(22186 22197, lpat(dot) lcol(black)) `bgopt' legend(off) xtit("Calendar date") ylab(,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(22183(7)22219, labsize(small)) text(40 22186 "Intervention" "begins", size(small) color(gray)) text(40 22197 "Due date of" "October 2020" "billing period", size(small) color(gray)) ytit(Cumulative payment rate (%)) text(36.5 22212 "Untreated (T=1)", color(navy%90)) text(30 22212 "Pure Control", color(maroon%90)) aspect(0.5) 
graph export "$Results\payment-rate-Oct2020-levels-untreated1.pdf", replace 

*levels C1 C2 C3 vs pure C
twoway (line pay_rate fpago_are if g_control==3, color(red%70)) (line pay_rate fpago_are if g_control==2, color(black%70) lpat(shortdash)) (line pay_rate fpago_are if g_control==1, color(blue%70) lpat(dash)) (line pay_rate fpago_are if g_control==0, color(maroon%60) lpat(dash)), xline(22186 22197, lpat(dot) lcol(black)) `bgopt' legend(off) xtit("Calendar date") ylab(,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(22183(7)22219, labsize(small)) text(40 22186 "Intervention" "begins", size(small) color(gray)) text(40 22197 "Due date of" "October 2020" "billing period", size(small) color(gray)) ytit(Cumulative payment rate (%)) text(37 22212 "Untreated groups", color(navy%90)) text(29 22212 "Pure Control", color(maroon%90)) aspect(0.5) 
graph export "$Results\payment-rate-Oct2020-levels-untreated123.pdf", replace 


*Treatment effects
sort fpago_are g_control
bysort fpago_are : gen difC1 = (pay_rate-pay_rate[_n-1]) if g_control==1 | g_control==0
bysort fpago_are : gen difC2 = (pay_rate-pay_rate[_n-2]) if g_control==2 | g_control==0
bysort fpago_are : gen difC3 = (pay_rate-pay_rate[_n-3]) if g_control==3 | g_control==0
bysort fpago_are : gen difT = (pay_rate-pay_rate[_n-4]) if g_control==4 | g_control==0

*all the groups
twoway (line difT fpago_are, color(gray%70)) (line difC3 fpago_are, color(red%70)) (line difC1 fpago_are, color(blue%70) lpat(dash)) (line difC2 fpago_are, color(black%70) lpat(shortdash)), xline(22186 22197, lpat(dot) lcol(black)) `bgopt' legend(off) xtit("Calendar date") ylab(0(1)5,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(22183(7)22219, labsize(small)) text(5 22186 "Intervention" "begins", size(small) color(gray)) text(5 22197 "Due date of" "October 2020" "billing period", size(small) color(gray)) ytit(Treatment effect (p.p.)) text(4.4 22212 "Treated" "(pooled)", size(small) color(gray%90)) text(1 22208 "T80", color(red%90)) text(-0.35 22208 "T20", color(blue%90)) text(0.25 22208 "T50", color(black%90)) aspect(0.5)
graph export "$Results\payment-rate-Oct2020-TE.pdf", replace 

*hide T=1 and T=2
twoway (line difT fpago_are, color(gray%70)) (line difC3 fpago_are, color(red%70)) (line difC1 fpago_are, color(blue%0) lpat(dash)) (line difC2 fpago_are, color(black%0) lpat(shortdash)), xline(22186 22197, lpat(dot) lcol(black)) `bgopt' legend(off) xtit("Calendar date") ylab(0(1)5,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(22183(7)22219, labsize(small)) text(5 22186 "Intervention" "begins", size(small) color(gray)) text(5 22197 "Due date of" "October 2020" "billing period", size(small) color(gray)) ytit(Treatment effect (p.p.)) text(4.4 22212 "Treated" "(pooled)", color(gray%90)) text(1.05 22211 "Untreated (T=3)", color(red%90)) aspect(0.5)
graph export "$Results\payment-rate-Oct2020-TE-v2.pdf", replace 

restore


***Break treated units into subgroups

preserve
replace g_treat=4 if control_123==1

*denominator
sum pago_cuota_oct20 if periodo==202010 & g_treat==0
loc Nc=r(N)
sum pago_cuota_oct20 if periodo==202010 & g_treat==1
loc Nt1=r(N)
sum pago_cuota_oct20 if periodo==202010 & g_treat==2
loc Nt2=r(N)
sum pago_cuota_oct20 if periodo==202010 & g_treat==3
loc Nt3=r(N)
sum pago_cuota_oct20 if periodo==202010 & g_treat==4
loc Nc123=r(N)

collapse (sum) Npayers=pago_cuota_oct20 if periodo==202010 & fpago_are<=mdy(10,31,2020) & fpago_are!=. & g_treat!=., by(fpago_are g_treat)
fillin g_treat fpago_are
sort g_treat fpago_are
bysort g_treat : gen cum = sum(Npayers)
drop if fpago_are<=mdy(9,15,2020)
gen pay_rate = cum/`Nc'*100 if g_treat==0
replace pay_rate = cum/`Nt1'*100 if g_treat==1
replace pay_rate = cum/`Nt2'*100 if g_treat==2
replace pay_rate = cum/`Nt3'*100 if g_treat==3
replace pay_rate = cum/`Nc123'*100 if g_treat==4


*levels T subgroups vs pure C
twoway (line pay_rate fpago_are if g_treat==1, color(blue%70) lpat(dash)) (line pay_rate fpago_are if g_treat==2, color(black%70) lpat(shortdash)) (line pay_rate fpago_are if g_treat==3, color(red%70)) (line pay_rate fpago_are if g_treat==0, color(maroon%60) lpat(dash)), xline(22186 22197, lpat(dot) lcol(black)) `bgopt' legend(off) xtit("Calendar date") ylab(,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(22183(7)22219, labsize(small)) text(40 22186 "Intervention" "begins", size(small) color(gray)) text(40 22197 "Due date of" "October 2020" "billing period", size(small) color(gray)) ytit(Cumulative payment rate (%)) text(41 22212 "Treated groups", color(navy%90)) text(30 22212 "Pure Control", color(maroon%90)) aspect(0.5) 
graph export "$Results\payment-rate-Oct2020-levels-treated-subgroups.pdf", replace 


*Treatment effects
sort fpago_are g_treat
bysort fpago_are : gen difT1 = (pay_rate-pay_rate[_n-1]) if g_treat==1 | g_treat==0
bysort fpago_are : gen difT2 = (pay_rate-pay_rate[_n-2]) if g_treat==2 | g_treat==0
bysort fpago_are : gen difT3 = (pay_rate-pay_rate[_n-3]) if g_treat==3 | g_treat==0
bysort fpago_are : gen difC  = (pay_rate-pay_rate[_n-4]) if g_treat==4 | g_treat==0

*all the groups
twoway (line difT1 fpago_are, color(blue%70) lpat(dash)) (line difT2 fpago_are, color(black%70) lpat(shortdash)) (line difT3 fpago_are, color(red%70)), xline(22186 22197, lpat(dot) lcol(black)) `bgopt' legend(off) xtit("Calendar date") ylab(0(1)5,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(22183(7)22219, labsize(small)) text(5 22186 "Intervention" "begins", size(small) color(gray)) text(5 22197 "Due date of" "October 2020" "billing period", size(small) color(gray)) ytit(Treatment effect (p.p.)) text(4.25 22212 "T20", color(blue%90)) text(5.3 22212 "T50", color(black%90)) text(4.7 22212 "T80", color(red%90)) aspect(0.5)
graph export "$Results\payment-rate-Oct2020-TE-subgroups.pdf", replace 

restore


