** Main analysis (placebo, cuota 9)
local bgopt "plotregion(icolor(white)) graphregion(fcolor(white) color(white)) bgcolor(white)"

*Open working database
use working_data.dta, clear
tab T tratado if periodo==202009


**********************************************
** Cuota 9 (September 2020)
** 1. Distribution of payment date by T vs C
** 2. Cumulative payment rate by calendar date
**********************************************

**Distribution of payment date by T vs C (for Cuota 9)
dis mdy(9,10,2020)
twoway (histogram fpago_are if periodo==202009 & fpago_are>mdy(8,15,2020) & fpago_are<=mdy(12,31,2020) & treat_123==1, color(navy%30) discrete frac) (histogram fpago_are if periodo==202009 & fpago_are>mdy(8,15,2020) & fpago_are<=mdy(12,31,2020) & treat_123==0, color(maroon%30) discrete frac), xline(22168.5 22185.5 22197.5, lpat(dash) lcol(gray)) `bgopt' legend(order(1 "Treated" 2 "Pure Control") ring(0) pos(1) row(2) region(style(none))) xtit("") ylab(0(.03).12,angle(0) nogrid) xlab(#7, labsize(small)) text(.12 22202 "Due date of" "Oct bill", size(small) color(gray)) text(.12 22172 "Due date of" "Sept bill", size(small) color(gray))
graph export "$Results\payments-density1-cuota9.pdf", replace 

twoway (histogram fpago_are if periodo==202009 & fpago_are>mdy(8,15,2020) & fpago_are<=mdy(12,31,2020) & control_123==1, color(navy%30) discrete frac) (histogram fpago_are if periodo==202009 & fpago_are>mdy(8,15,2020) & fpago_are<=mdy(12,31,2020) & control_123==0, color(maroon%30) discrete frac), xline(22168.5 22185.5 22197.5, lpat(dash) lcol(gray)) `bgopt' legend(order(1 "Untreated" 2 "Pure Control") ring(0) pos(1) row(2) region(style(none))) xtit("") ylab(0(.03).12,angle(0) nogrid) xlab(#7, labsize(small)) text(.12 22202 "Due date of" "Oct bill", size(small) color(gray)) text(.12 22172 "Due date of" "Sept bill", size(small) color(gray))
graph export "$Results\payments-density2-cuota9.pdf", replace 


**Cumulative payment rate (%) and difference between T=0,1,2,3

***Break untreated units into subgroups; pool treated units

preserve
replace g_control=4 if treat_123==1

*denominator
sum pago_cuota_oct20 if periodo==202009 & g_control==0
loc Nc=r(N)
sum pago_cuota_oct20 if periodo==202009 & g_control==1
loc Nc1=r(N)
sum pago_cuota_oct20 if periodo==202009 & g_control==2
loc Nc2=r(N)
sum pago_cuota_oct20 if periodo==202009 & g_control==3
loc Nc3=r(N)
sum pago_cuota_oct20 if periodo==202009 & g_control==4
loc Nt=r(N)

collapse (sum) Npayers=pago_cuota_oct20 if periodo==202009 & fpago_are<=mdy(9,27,2020) & fpago_are!=. & g_control!=., by(fpago_are g_control)
fillin g_control fpago_are
sort g_control fpago_are
bysort g_control : gen cum = sum(Npayers)
drop if fpago_are<=mdy(8,24,2020)
gen pay_rate = cum/`Nt'*100 if g_control==4
replace pay_rate = cum/`Nc'*100 if g_control==0
replace pay_rate = cum/`Nc1'*100 if g_control==1
replace pay_rate = cum/`Nc2'*100 if g_control==2
replace pay_rate = cum/`Nc3'*100 if g_control==3

*levels T vs pure C
twoway (line pay_rate fpago_are if g_control==4, color(navy%70)) (line pay_rate fpago_are if g_control==0, color(maroon%60) lpat(dash)), xline(22168 22186 22197, lpat(dot) lcol(black)) `bgopt' legend(off) xtit("Calendar date") ylab(,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(22152(11)22219, labsize(small)) text(40 22186 "Intervention" "begins", size(small) color(gray)) text(40 22168 "Due date of" "Sept 2020 bill", size(small) color(gray)) text(40 22197 "Due date of" "Oct 2020 bill", size(small) color(gray)) ytit(Cumulative payment rate (%)) text(41 22212 "Treated (pooled)", color(navy%90)) text(34 22212 "Pure Control", color(maroon%90)) aspect(0.5) 
graph export "$Results\payment-rate-Sep2020-levels-treated.pdf", replace 

*levels C1 C2 C3 vs pure C
twoway (line pay_rate fpago_are if g_control==3, color(red%70)) (line pay_rate fpago_are if g_control==2, color(black%70) lpat(shortdash)) (line pay_rate fpago_are if g_control==1, color(blue%70) lpat(dash)) (line pay_rate fpago_are if g_control==0, color(maroon%60) lpat(dash)), xline(22168 22186 22197, lpat(dot) lcol(black)) `bgopt' legend(off) xtit("Calendar date") ylab(,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(22152(11)22219, labsize(small)) text(40 22186 "Intervention" "begins", size(small) color(gray)) text(40 22168 "Due date of" "Sept 2020 bill", size(small) color(gray)) text(40 22197 "Due date of" "Oct 2020 bill", size(small) color(gray)) ytit(Cumulative payment rate (%)) text(39 22212 "Untreated groups", color(navy%90)) text(33 22212 "Pure Control", color(maroon%90)) aspect(0.5) 
graph export "$Results\payment-rate-Sep2020-levels-untreated123.pdf", replace 


*Treatment effects
sort fpago_are g_control
bysort fpago_are : gen difC1 = (pay_rate-pay_rate[_n-1]) if g_control==1 | g_control==0
bysort fpago_are : gen difC2 = (pay_rate-pay_rate[_n-2]) if g_control==2 | g_control==0
bysort fpago_are : gen difC3 = (pay_rate-pay_rate[_n-3]) if g_control==3 | g_control==0
bysort fpago_are : gen difT = (pay_rate-pay_rate[_n-4]) if g_control==4 | g_control==0

*all the groups
twoway (line difC3 fpago_are, color(red%70)) (line difC1 fpago_are, color(blue%70) lpat(dash)) (line difC2 fpago_are, color(black%70) lpat(shortdash)), xline(22168 22186, lpat(dot) lcol(black)) `bgopt' legend(off) xtit("Calendar date") ylab(0(1)5,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(22152(11)22187) text(5 22186 "Intervention" "begins", size(small) color(gray)) text(5 22168 "Due date of" "Sept 2020 bill", color(gray)) ytit(Treatment effect (p.p.)) text(.8 22185 "T20", color(blue%90)) text(-0.35 22185 "T80", color(red%90)) text(0.25 22185 "T50", color(black%90)) aspect(0.5)
graph export "$Results\payment-rate-Sep2020-TE.pdf", replace  

restore


***Break treated units into subgroups

preserve
replace g_treat=4 if control_123==1

*denominator
sum pago_cuota_oct20 if periodo==202009 & g_treat==0
loc Nc=r(N)
sum pago_cuota_oct20 if periodo==202009 & g_treat==1
loc Nt1=r(N)
sum pago_cuota_oct20 if periodo==202009 & g_treat==2
loc Nt2=r(N)
sum pago_cuota_oct20 if periodo==202009 & g_treat==3
loc Nt3=r(N)
sum pago_cuota_oct20 if periodo==202009 & g_treat==4
loc Nc123=r(N)

collapse (sum) Npayers=pago_cuota_oct20 if periodo==202009 & fpago_are<=mdy(9,27,2020) & fpago_are!=. & g_treat!=., by(fpago_are g_treat)
fillin g_treat fpago_are
sort g_treat fpago_are
bysort g_treat : gen cum = sum(Npayers)
drop if fpago_are<=mdy(8,24,2020)
gen pay_rate = cum/`Nc'*100 if g_treat==0
replace pay_rate = cum/`Nt1'*100 if g_treat==1
replace pay_rate = cum/`Nt2'*100 if g_treat==2
replace pay_rate = cum/`Nt3'*100 if g_treat==3
replace pay_rate = cum/`Nc123'*100 if g_treat==4


*levels T subgroups vs pure C
twoway (line pay_rate fpago_are if g_treat==1, color(blue%70) lpat(dash)) (line pay_rate fpago_are if g_treat==2, color(black%70) lpat(shortdash)) (line pay_rate fpago_are if g_treat==3, color(red%70)) (line pay_rate fpago_are if g_treat==0, color(maroon%60) lpat(dash)), xline(22168 22186 22197, lpat(dot) lcol(black)) `bgopt' legend(off) xtit("Calendar date") ylab(,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(22152(11)22219, labsize(small)) text(40 22186 "Intervention" "begins", size(small) color(gray)) text(40 22168 "Due date of" "Sept 2020 bill", size(small) color(gray)) text(40 22197 "Due date of" "Oct 2020 bill", size(small) color(gray)) ytit(Cumulative payment rate (%)) text(41 22212 "Treated groups", color(navy%90)) text(34 22212 "Pure Control", color(maroon%90)) aspect(0.5) 
graph export "$Results\payment-rate-Sep2020-levels-treated-subgroups.pdf", replace 


*Treatment effects
sort fpago_are g_treat
bysort fpago_are : gen difT1 = (pay_rate-pay_rate[_n-1]) if g_treat==1 | g_treat==0
bysort fpago_are : gen difT2 = (pay_rate-pay_rate[_n-2]) if g_treat==2 | g_treat==0
bysort fpago_are : gen difT3 = (pay_rate-pay_rate[_n-3]) if g_treat==3 | g_treat==0
bysort fpago_are : gen difC  = (pay_rate-pay_rate[_n-4]) if g_treat==4 | g_treat==0

*all the groups
twoway (line difT1 fpago_are, color(blue%70) lpat(dash)) (line difT2 fpago_are, color(black%70) lpat(shortdash)) (line difT3 fpago_are, color(red%70)), xline(22168 22186, lpat(dot) lcol(black)) `bgopt' legend(off) xtit("Calendar date") ylab(0(1)5,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(22152(11)22187) text(5 22186 "Intervention" "begins", size(small) color(gray)) text(5 22168 "Due date of" "Sept 2020 bill", color(gray)) ytit(Treatment effect (p.p.)) text(1.2 22185 "T20", color(blue%90)) text(0.6 22185 "T50", color(black%90)) text(0.1 22185 "T80", color(red%90)) aspect(0.5)
graph export "$Results\payment-rate-Sep2020-TE-subgroups.pdf", replace 

restore


**********************************************
** Saturated regressions - September 2020
**********************************************
*Saturated regression to jointly estimate all the parameters
*Standard errors clustered by blocks (num_cuadra)

*******************
** Figures with CI
*******************

**Rectangularize dataset 
*(to obtain a balanced daily panel)
preserve
keep if periodo==202009
keep id fpago_are pago_cuota treat1 treat2 treat3 control1 control2 control3 num_cuadra
fillin id fpago_are

*payment dummy (=1 after people paid the Sept 2020 bill)
sort id fpago_are
bys id: gen paid_bill = sum( pago_cuota )

*expand num_cuadra
sort id num_cuadra
by id : replace num_cuadra = num_cuadra[1]
sort id fpago_are

*expand T/C status
foreach var of varlist treat1-control3 {
  egen d`var'=max(`var'), by(id)
}

*keep relevant subperiod
keep if ( fpago_are>=mdy(9,1,2020) & fpago_are<=mdy(9,27,2020) )

*date relative to start of intervention
gen t = fpago_are-mdy(9,27,2020)
xi i.t, pref(_T)

tab fpago_are, gen(_T)
di mdy(9,27,2020)

*Saturated regression with all groups

foreach g of varlist dtreat1 dtreat2 dtreat3 dcontrol1 dcontrol2 dcontrol3 {
foreach var of varlist _T1-_T27 {
  gen `g'`var' = `var'*`g'
}
}

set matsize 2000
reg paid_bill dtreat1_T1-dcontrol3_T27 _T1-_T27, cluster(num_cuadra) nocons
*reg subscribed dtreat1_Tt_1-dcontrol3_Tt_31 _Tt_1-_Tt_31 dtreat1 dtreat2 dtreat3 dcontrol1 dcontrol2 dcontrol3, cluster(num_cuadra)

matrix A = r(table)
*treated
matrix T1 = ( (A[1,1..27])' , (A[5,1..27])' , (A[6,1..27])' ) * 100
matrix T2 = ( (A[1,28..54])' , (A[5,28..54])' , (A[6,28..54])' ) * 100
matrix T3 = ( (A[1,55..81])' , (A[5,55..81])' , (A[6,55..81])' ) * 100
*untreated
matrix C1 = ( (A[1,82..108])' , (A[5,82..108])' , (A[6,82..108])' ) * 100
matrix C2 = ( (A[1,109..135])' , (A[5,109..135])' , (A[6,109..135])' ) * 100
matrix C3 = ( (A[1,136..162])' , (A[5,136..162])' , (A[6,136..162])' ) * 100
matrix R = T1,T2,T3,C1,C2,C3
svmat R
gen xvar = _n+22158 if _n<=27
format xvar %td


**treated
twoway (rspike R2 R3 xvar, sort color(navy%40) msize(*.5)) (connected R1 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22159(7)22187) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(black) lpat(dot)) legend(off) xline(22168 22186, lpat(dot) lcol(black)) title("{bf:Blocks with 20% treated}", suffix) name(g1, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(small) color(gray)) text(6.5 22165 "Due date of" "Sept 2020 bill", color(gray))
graph export "$Results\payment-rate-cuota9-diff-treated1.pdf", replace 

twoway (rspike R5 R6 xvar, sort color(navy%40) msize(*.5)) (connected R4 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22159(7)22187) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(black) lpat(dot)) legend(off) xline(22168 22186, lpat(dot) lcol(black)) title("{bf:Blocks with 50% treated}", suffix) name(g2, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(small) color(gray)) text(6.5 22165 "Due date of" "Sept 2020 bill", color(gray))
graph export "$Results\payment-rate-cuota9-diff-treated2.pdf", replace 

twoway (rspike R8 R9 xvar, sort color(navy%40) msize(*.5)) (connected R7 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22159(7)22187) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(black) lpat(dot)) legend(off) xline(22168 22186, lpat(dot) lcol(black)) title("{bf:Blocks with 80% treated}", suffix) name(g3, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(small) color(gray)) text(6.5 22165 "Due date of" "Sept 2020 bill", color(gray))
graph export "$Results\payment-rate-cuota9-diff-treated3.pdf", replace 

**untreated
twoway (rspike R11 R12 xvar, sort color(navy%40) msize(*.5)) (connected R10 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22159(7)22187) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(black) lpat(dot)) legend(off) xline(22168 22186, lpat(dot) lcol(black)) title("{bf:Blocks with 20% treated}", suffix) name(g1, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(small) color(gray)) text(6.5 22165 "Due date of" "Sept 2020 bill", color(gray))
graph export "$Results\payment-rate-cuota9-diff-untreated1.pdf", replace 

twoway (rspike R14 R15 xvar, sort color(navy%40) msize(*.5)) (connected R13 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22159(7)22187) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(black) lpat(dot)) legend(off) xline(22168 22186, lpat(dot) lcol(black)) title("{bf:Blocks with 50% treated}", suffix) name(g2, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(small) color(gray)) text(6.5 22165 "Due date of" "Sept 2020 bill", color(gray))
graph export "$Results\payment-rate-cuota9-diff-untreated2.pdf", replace 

twoway (rspike R17 R18 xvar, sort color(navy%40) msize(*.5)) (connected R16 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(22159(7)22187) ylab(0(1)7, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(black) lpat(dot)) legend(off) xline(22168 22186, lpat(dot) lcol(black)) title("{bf:Blocks with 80% treated}", suffix) name(g3, replace) aspect(.5) text(7 22186 "Intervention" "begins", size(small) color(gray)) text(6.5 22165 "Due date of" "Sept 2020 bill", color(gray))
graph export "$Results\payment-rate-cuota9-diff-untreated3.pdf", replace

restore



