** Main analysis
local bgopt "plotregion(icolor(white)) graphregion(fcolor(white) color(white)) bgcolor(white)"

*Open working database
use working_data.dta, clear
tab T tratado if periodo==202010


**********************************************
** TOTAL EFFECTS (Diff-in-Diffs)
**********************************************
local dates "201901 201902 201903 201904 201905 201906 201907 201908 201909 201910 201911 201912 202001 202002 202003 202004 202005 202006 202007 202008 202009 202010 202011 202012"
local dates_pre "201901 201902 201903 201904 201905 201906 201907 201908 201909 201910 201911 201912 202001 202002 202003 202004 202005 202006 202007 202008 202009"

gen treat=treat_123

tab pago_cuota_mismo_mes if periodo==202010
tab fpago_are if periodo==202010 & pago_cuota_mismo_mes==1

*Timely payments (up to the 27th of each month)
gen day = day(fpago_are)
gen month = month(fpago_are)
tab day

gen pago_timely=pago_cuota_mismo_mes
replace pago_timely=0 if day>27 & day!=. & month==cuota
*replace pago_timely=. if periodo>202009
tab pago_timely if periodo==202009, m
drop day month


********************************************
*** Pre-intervention payments (benchmark)
********************************************

mat A1 = J(1,5,.)
foreach ym of local dates_pre {

  display in red " -------> Period -------> `ym'"
  * Monto (levels)
  regress monto_pago_pre treat if periodo==`ym', cluster(num_cuadra)
  mat b1=_b[treat]
  * Monto (logs)
  regress ihs_monto_pre treat if periodo==`ym', cluster(num_cuadra)
  mat b2=_b[treat]
  * Pr(pago)
  regress pago_cuota_pre treat if periodo==`ym', cluster(num_cuadra)
  matrix A=r(table)
  mat b3=A[1,1]*100
  mat ll3=A[5,1]*100
  mat ul3=A[6,1]*100
  
  mat A1=A1\(b1,b2,b3,ll3,ul3)

}
mat colnames A1 = "dd_monto_old" "dd_lmonto_old" "dd_pago_old" "dd_ll_old" "dd_ul_old" 
svmat A1, names(col)

*Timely payments
mat A1 = J(1,7,.)
foreach ym of local dates {

  display in red " -------> Period -------> `ym'"
  *Timely payments
  regress pago_timely treat if periodo==`ym', cluster(num_cuadra)
  mat bT=(_b[_cons]+_b[treat])*100
  mat bC=_b[_cons]*100
  matrix A=r(table)
  mat b=A[1,1]*100
  mat se=A[2,1]*100
  mat ll=A[5,1]*100
  mat ul=A[6,1]*100
  
  mat A1=A1\(`ym',b,se,ll,ul,bT,bC)

}
mat colnames A1 = "period" "dd_pre" "se_pre" "dd_ll_pre" "dd_ul_pre" "bT_pre" "bC_pre"
svmat A1, names(col)
gen aniocuota = ym(floor(period/100), mod(period, 100))
format aniocuota %tm
gen aniocuota_aux=aniocuota+.2

********************************************
*** Probability to pay
********************************************
mat A1 = J(1,6,.)
foreach ym of local dates {

  display in red " -------> Period -------> `ym'"

  regress pago_cuota_dec20 treat if periodo==`ym', cluster(num_cuadra)
  mat bT=(_b[_cons]+_b[treat])*100
  mat bC=_b[_cons]*100
  matrix A=r(table)
  mat b=A[1,1]*100
  mat se=A[2,1]*100
  mat ll=A[5,1]*100
  mat ul=A[6,1]*100
  mat A1=A1\(b,se,ll,ul,bT,bC)

}

mat colnames A1 = "dd" "se" "dd_ll" "dd_ul" "bT" "bC"
svmat A1, names(col)


*Levels (timely and past-due payments)
twoway (connected bT bC aniocuota, msy(O X) mcol(black gray) lcol(black gray) mlcol(black gray)) (pcarrowi 55 722.6 55 725, lcol(gray) mcolor(gray)), `bgopt' xlabel(#10,angle(0) labsize(small)) ylab(20(5)60, nogrid angle(0)) subtitle("% paid the bill", placement(7) span) xtit("Billing Period") aspect(0.5) legend(order(1 "Treated (pooled)" 2 "Pure Control") ring(0) pos(9) col(1) region(style(none))) xline(722.5 729, lpat(dot) lcol(gray)) text(60 725 "COVID-19" "billing periods", color(gray)) text(60 731 "Intervention" "bill", color(navy))
graph export "$Results\\Level-probpay.pdf", replace 

*Levels (timely payments)
twoway (connected bT_pre bC_pre aniocuota, msy(O X) mcol(black gray) lcol(black gray) mlcol(black gray)) (pcarrowi 55 722.6 55 725, lcol(gray) mcolor(gray)), `bgopt' xlabel(#10,angle(0) labsize(small)) ylab(20(5)60, nogrid angle(0)) subtitle("% paid the bill", placement(7) span) xtit("Billing Period") aspect(0.5) legend(order(1 "Treated (pooled)" 2 "Pure Control") ring(0) pos(9) col(1) region(style(none))) xline(722.5 729, lpat(dot) lcol(gray)) text(60 725 "COVID-19" "billing periods", color(gray)) text(60 731 "Intervention" "bill", color(navy))
graph export "$Results\\Level-probpay-timely.pdf", replace 

*for slides
twoway (connected bT_pre bC_pre aniocuota if aniocuota<=ym(2020,9), msy(O X) mcol(black gray) lcol(black gray) mlcol(black gray)) (pcarrowi 55 722.6 55 725, lcol(gray) mcolor(gray)), `bgopt' xlabel(708(3)732,angle(0) labsize(small)) ylab(20(5)60, nogrid angle(0)) subtitle("% paid the bill", placement(7) span) xtit("Billing Period") aspect(0.5) legend(order(1 "Treated (pooled)" 2 "Pure Control") ring(0) pos(9) col(1) region(style(none))) xline(722.5 729, lpat(dot) lcol(gray)) text(60 725 "COVID-19" "billing periods", color(gray)) text(60 731 "Intervention" "bill", color(navy))
graph export "$Results\\Level-probpay-timely-slides.pdf", replace 

*DD estimate (timely and past-due payments)
twoway (rspike dd_ll dd_ul aniocuota, sort color(navy%40) msize(*.5)) (connected dd aniocuota, msy(O) mcol(navy*.3) lcol(navy) mlcol(navy)) (pcarrowi 5.2 722.6 5.2 725, lcol(gray) mcolor(gray)), `bgopt' xlabel(#10, angle(0) labsize(small)) ylab(-1(1)6,nogrid angle(0)) subtitle("Treatment" "effect (p.p.)", placement(7) span) xtit("Billing Period") yline(0, lcol(black)) aspect(0.5) legend(off) text(4.5 731 "Oct 2020:" "4.2 p.p.", size(medsmall)) text(6 725 "COVID-19" "billing periods", color(gray)) xline(722.5, lpat(dot) lcol(gray))
graph export "$Results\DinD-probpay.pdf", replace 

*DD estimate (timely payments)
twoway (rspike dd_ll_pre dd_ul_pre aniocuota, sort color(maroon%40) msize(*.5)) (connected dd_pre aniocuota, msy(O) mcol(maroon*.3) lcol(maroon) mlcol(maroon)) (pcarrowi 5.2 722.6 5.2 725, lcol(gray) mcolor(gray)), `bgopt' xlabel(#10, angle(0) labsize(small)) ylab(-1(1)6,nogrid angle(0)) subtitle("Treatment" "effect (p.p.)", placement(7) span) xtit("Billing Period") yline(0, lcol(black)) aspect(0.5) legend(off) text(4.5 731 "Oct 2020:" "4.4 p.p.", size(medsmall)) text(6 725 "COVID-19" "billing periods", color(gray)) xline(722.5, lpat(dot) lcol(gray))
graph export "$Results\DinD-probpay-timely.pdf", replace 


/*
Effect in October for T=1,2,3:
.0529127/.3934927
.0342907/.4015241
.0336667/.4038618
*/

*Scale the effect relative to the control group
gen dd_pre_overC = dd_pre/bC_pre*100
gen dd_overC = dd/bC*100
gen dd_ll_overC = dd_ll/bC*100
gen dd_ul_overC = dd_ul/bC*100
twoway (rcap dd_ll_overC dd_ul_overC aniocuota, sort color(navy%40) msize(*.5)) (connected dd_overC aniocuota, msy(O) mcol(navy*.3) lcol(navy) mlcol(navy)) (connected dd_pre_overC aniocuota, msy(X) mcol(maroon*.3) lcol(maroon%50) mlcol(maroon%50)) (pcarrowi 12 722.6 12 724, lcol(gray) mcolor(gray)), `bgopt' xlabel(#10, angle(0) labsize(small)) ylab(#7,nogrid angle(0)) ytit(ITT relative to payment rate of C (%)) xtit("Billing Period") yline(0, lcol(black)) aspect(0.5) legend(off) text(12 731 "Oct 2020: 10.6%" "relative to C", size(small)) text(15 725 "Pandemic" "billing periods", color(gray)) xline(722.5, lpat(dot) lcol(gray))
graph export "$Results\DinD-probpay-wrtC.pdf", replace 

drop period-dd_ul_overC



