local bgopt "plotregion(icolor(white)) graphregion(fcolor(white) color(white)) bgcolor(white)"

***************************************************
** Subscriptions to paperless electronic billing
***************************************************

**********************************************
** Prepare database
**********************************************

import excel using "suscripciones_20210308.xlsx", clear first
tab ImpuestoTasa
tab Relación
rename Objetos nro_cuenta
sort nro_cuenta

*a few duplicates, let's keep one random or drop them (it doesn't change the results)
duplicates tag nro_cuenta, gen(tag)
tab tag
drop if tag>0
*duplicates drop nro_cuenta, force
duplicates tag Correoelectrónico, gen(tag_email)

gen day = substr(FechadeAlta,1,2)
gen month = substr(FechadeAlta,4,2)
gen year = substr(FechadeAlta,7,4)
destring day month year, replace
gen date_subscribe = mdy(month, day, year)
format date_subscribe %d

gen periodo=string(year)+"0"+string(month) if month<=9
replace periodo=string(year)+string(month) if month>9
destring periodo, replace

keep if ImpuestoTasa=="Tasa Servicios Generales"
keep nro_cuenta Relación tag_email month year date_subscribe periodo

** Merge with Baseline data with T and C groups
*merge m:1 nro_cuenta using "2 - Base total con datos imprenta.dta"
merge m:1 nro_cuenta using "randomization_final.dta"
tab _merge if T!=.
tab _merge if T==.
drop if _merge==1

tab _merge if T!=.
tab _merge if T==.
tab T if _merge==3
tab month if year==2020
tab month if year==2021
keep if T!=.

** Merge with main data to get block-id for standard errors
merge 1:m id using "Base 1 Cuenta Corriente por Cuenta al 10Mar.dta", keepusing(num_cuadra cuota anio) gen(merge_maindata)
drop if merge_maindata==2

tab cuota if anio==2020
keep if anio==2020 & cuota==10
drop anio cuota

gen boleta_digital=0 if _merge==2
replace boleta_digital=1 if _merge==3
tab boleta_digital
tab month tratado


**********************************************
** Create dummy variables
**********************************************

**groups for total effects
gen treat1=0 if T!=.
replace treat1=1 if tratado==1 & T==1
gen treat2=0 if T!=.
replace treat2=1 if tratado==1 & T==2
gen treat3=0 if T!=.
replace treat3=1 if tratado==1 & T==3

gen treat_123=0 if T==0
replace treat_123=1 if tratado==1

gen g_treat=0 if T==0
replace g_treat=1 if tratado==1 & T==1
replace g_treat=2 if tratado==1 & T==2
replace g_treat=3 if tratado==1 & T==3

**groups for spillover effects
gen control1=0 if T!=.
replace control1=1 if tratado==0 & T==1
gen control2=0 if T!=.
replace control2=1 if tratado==0 & T==2
gen control3=0 if T!=.
replace control3=1 if tratado==0 & T==3

gen control_123=0 if T==0
replace control_123=1 if tratado==0 & (T==1 | T==2 | T==3)

gen g_control=0 if T==0
replace g_control=1 if tratado==0 & T==1
replace g_control=2 if tratado==0 & T==2
replace g_control=3 if tratado==0 & T==3

*Accounts per block (cuadra)
bysort num_cuadra: gen gsize = _N
replace tag_email=0 if tag_email==.

**********************************************
** Analysis
**********************************************

reg boleta_digital tratado, cluster(num_cuadra)
reg boleta_digital treat1 treat2 treat3 control1 control2 control3, cluster(num_cuadra)


**Cumulative subscription rate (%) and difference between T=0,1,2,3
preserve
local group ""
replace g_control=4 if treat_123==1

*denominator
sum boleta_digital if g_control==0 `group'
loc Nc=r(N)
sum boleta_digital if g_control==1 `group'
loc Nc1=r(N)
sum boleta_digital if g_control==2 `group'
loc Nc2=r(N)
sum boleta_digital if g_control==3 `group'
loc Nc3=r(N)
sum boleta_digital if g_control==4 `group'
loc Nt=r(N)

collapse (sum) Nsubscribers=boleta_digital if date_subscribe<=mdy(12,31,2020) `group', by(date_subscribe g_control)
fillin g_control date_subscribe
sort g_control date_subscribe
bysort g_control : gen cum = sum(Nsubscribers)
gen subscription_rate = cum/`Nt'*100 if g_control==4
replace subscription_rate = cum/`Nc'*100 if g_control==0
replace subscription_rate = cum/`Nc1'*100 if g_control==1
replace subscription_rate = cum/`Nc2'*100 if g_control==2
replace subscription_rate = cum/`Nc3'*100 if g_control==3

*levels: pooled T vs pure C
twoway (line subscription_rate date_subscribe if g_control==4, color(navy%70)) (line subscription_rate date_subscribe if g_control==0, color(maroon%60) lpat(dash)), xline(22186 22197, lpat(dot) lcol(gray)) `bgopt' legend(off) xtit("Calendar date") ylab(,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(#7, labsize(small)) text(8 22178 "Intervention" "begins", size(small) color(gray)) text(8 22210 "Due date of" "October 2020" "billing period", size(small) color(gray)) ytit(Cumulative subscription rate (%)) text(6.8 22222 "Treated", size(small) color(navy%90)) text(4.5 22232 "Pure Control", size(small) color(maroon%90)) aspect(0.5) 
graph export "$Results\subscription-rate-levels-treated.pdf", replace 

*levels: C3 vs pure C
twoway (line subscription_rate date_subscribe if g_control==3, color(navy%70)) (line subscription_rate date_subscribe if g_control==0, color(maroon%60) lpat(dash)), xline(22186 22197, lpat(dot) lcol(gray)) `bgopt' legend(off) xtit("Calendar date") ylab(0(2)8,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(#7, labsize(small)) text(8 22178 "Intervention" "begins", size(small) color(gray)) text(8 22210 "Due date of" "October 2020" "billing period", size(small) color(gray)) ytit(Cumulative subscription rate (%)) text(7 22242 "Untreated (T=3)", size(small) color(navy%90)) text(4.5 22232 "Pure Control", size(small) color(maroon%90)) aspect(0.5)
graph export "$Results\subscription-rate-levels-untreated3.pdf", replace 

*levels: C2 vs pure C
twoway (line subscription_rate date_subscribe if g_control==2, color(navy%70)) (line subscription_rate date_subscribe if g_control==0, color(maroon%60) lpat(dash)), xline(22186 22197, lpat(dot) lcol(gray)) `bgopt' legend(off) xtit("Calendar date") ylab(0(2)8,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(#7, labsize(small)) text(8 22178 "Intervention" "begins", size(small) color(gray)) text(8 22210 "Due date of" "October 2020" "billing period", size(small) color(gray)) ytit(Cumulative subscription rate (%)) text(6.2 22242 "Untreated (T=2)", size(small) color(navy%90)) text(4.5 22232 "Pure Control", size(small) color(maroon%90)) aspect(0.5)
graph export "$Results\subscription-rate-levels-untreated2.pdf", replace 

*levels: C1 vs pure C
twoway (line subscription_rate date_subscribe if g_control==1, color(navy%70)) (line subscription_rate date_subscribe if g_control==0, color(maroon%60) lpat(dash)), xline(22186 22197, lpat(dot) lcol(gray)) `bgopt' legend(off) xtit("Calendar date") ylab(0(2)8,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(#7, labsize(small)) text(8 22178 "Intervention" "begins", size(small) color(gray)) text(8 22210 "Due date of" "October 2020" "billing period", size(small) color(gray)) ytit(Cumulative subscription rate (%)) text(6 22242 "Untreated (T=1)", size(small) color(navy%90)) text(4.3 22232 "Pure Control", size(small) color(maroon%90)) aspect(0.5)
graph export "$Results\subscription-rate-levels-untreated1.pdf", replace 

*levels: C1 C2 C3 vs pure C
twoway (line subscription_rate date_subscribe if g_control==1, color(blue%70) lpat(dash)) (line subscription_rate date_subscribe if g_control==2, color(black%70) lpat(shortdash)) (line subscription_rate date_subscribe if g_control==3, color(red%70)) (line subscription_rate date_subscribe if g_control==0, color(maroon%90) lpat(-.)), xline(22186 22197, lpat(dot) lcol(black)) `bgopt' legend(off) xtit("Calendar date") ylab(0(2)8,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(#7, labsize(small)) text(8 22178 "Intervention" "begins", size(small) color(gray)) text(8 22210 "Due date of" "October 2020" "billing period", size(small) color(gray)) ytit(Cumulative subscription rate (%)) text(4.4 22232 "Pure Control", size(small) color(maroon%90)) text(5.1 22272 "T=1", size(small) color(blue%90)) text(6.1 22272 "T=2", size(small) color(black%90)) text(6.9 22272 "T=3", size(small) color(red%90)) aspect(0.5)
graph export "$Results\subscription-rate-levels-untreated-subgroups.pdf", replace 


*difference:
sort date_subscribe g_control
bysort date_subscribe : gen difC1 = (subscription_rate-subscription_rate[_n-1]) if g_control==1 | g_control==0
bysort date_subscribe : gen difC2 = (subscription_rate-subscription_rate[_n-2]) if g_control==2 | g_control==0
bysort date_subscribe : gen difC3 = (subscription_rate-subscription_rate[_n-3]) if g_control==3 | g_control==0
bysort date_subscribe : gen difT = (subscription_rate-subscription_rate[_n-4]) if g_control==4 | g_control==0

*hide T=1 and T=2
twoway (line difT date_subscribe if date_subscribe<=22340, color(navy%70)) (line difC3 date_subscribe if date_subscribe<=22340, color(red%60) lpat(shortdash)) (line difC1 date_subscribe if date_subscribe<=22340, color(gray%0)) (line difC2 date_subscribe if date_subscribe<=22340, color(gray%0)), xline(22186 22197, lpat(dot) lcol(black)) `bgopt' legend(off) xtit("Calendar date") ylab(0(1)3,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(#6, labsize(small)) text(3 22178 "Intervention" "begins", size(small) color(gray)) text(3 22210 "Due date of" "October 2020" "billing period", size(small) color(gray)) ytit(Treatment effect (p.p.)) text(1.5 22250 "Total effect (pooled)", size(small) color(navy%90)) text(.8 22250 "Spillover effect (T=3)", size(small) color(red%90)) aspect(0.5)
graph export "$Results\subscription-rate-TE-v2.pdf", replace 

*all the groups
twoway (line difT date_subscribe if date_subscribe<=22340, color(gray%70)) (line difC3 date_subscribe if date_subscribe<=22340, color(red%70)) (line difC1 date_subscribe if date_subscribe<=22340, color(blue%70) lpat(dash)) (line difC2 date_subscribe if date_subscribe<=22340, color(black%70) lpat(shortdash)), xline(22186 22197, lpat(dot) lcol(black)) `bgopt' legend(off) xtit("Calendar date") ylab(0(1)3,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(#6, labsize(small)) text(3 22178 "Intervention" "begins", size(small) color(gray)) text(3 22210 "Due date of" "October 2020" "billing period", size(small) color(gray)) ytit(Treatment effect (p.p.)) text(1.5 22250 "Total effect (pooled)", size(small) color(gray%90)) text(.85 22272 "T=3", size(small) color(red%90)) text(-.17 22272 "T=1", size(small) color(blue%90)) text(0.42 22272 "T=2", size(small) color(black%90)) aspect(0.5)
graph export "$Results\subscription-rate-TE.pdf", replace 
restore


** Break treated into subgroups
preserve
local group ""

*denominator
sum boleta_digital if g_treat==0 `group'
loc Nc=r(N)
sum boleta_digital if g_treat==1 `group'
loc Nt1=r(N)
sum boleta_digital if g_treat==2 `group'
loc Nt2=r(N)
sum boleta_digital if g_treat==3 `group'
loc Nt3=r(N)

collapse (sum) Nsubscribers=boleta_digital if date_subscribe<=mdy(12,31,2020) `group', by(date_subscribe g_treat)
fillin g_treat date_subscribe
sort g_treat date_subscribe
bysort g_treat : gen cum = sum(Nsubscribers)
gen subscription_rate = cum/`Nc'*100 if g_treat==0
replace subscription_rate = cum/`Nt1'*100 if g_treat==1
replace subscription_rate = cum/`Nt2'*100 if g_treat==2
replace subscription_rate = cum/`Nt3'*100 if g_treat==3

*levels: T subgroups vs pure C
twoway (line subscription_rate date_subscribe if g_treat==1, color(blue%70) lpat(dash)) (line subscription_rate date_subscribe if g_treat==2, color(black%70) lpat(shortdash)) (line subscription_rate date_subscribe if g_treat==3, color(red%70)) (line subscription_rate date_subscribe if g_treat==0, color(maroon%60) lpat(-.)), xline(22186 22197, lpat(dot) lcol(black)) `bgopt' legend(off) xtit("Calendar date") ylab(,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(#7, labsize(small)) text(8 22178 "Intervention" "begins", size(small) color(gray)) text(8 22210 "Due date of" "October 2020" "billing period", size(small) color(gray)) ytit(Cumulative subscription rate (%)) text(4.5 22232 "Pure Control", size(small) color(maroon%90)) text(6.1 22272 "T=1", size(small) color(blue%90)) text(6.9 22272 "T=2", size(small) color(black%90)) text(7.5 22272 "T=3", size(small) color(red%90)) aspect(0.5) 
graph export "$Results\subscription-rate-levels-treated-subgroups.pdf", replace 


*difference:
sort date_subscribe g_treat
bysort date_subscribe : gen difT1 = (subscription_rate-subscription_rate[_n-1]) if g_treat==1 | g_treat==0
bysort date_subscribe : gen difT2 = (subscription_rate-subscription_rate[_n-2]) if g_treat==2 | g_treat==0
bysort date_subscribe : gen difT3 = (subscription_rate-subscription_rate[_n-3]) if g_treat==3 | g_treat==0

*all the groups
twoway (line difT1 date_subscribe if date_subscribe<=22340, color(blue%70) lpat(dash)) (line difT2 date_subscribe if date_subscribe<=22340, color(black%70) lpat(shortdash)) (line difT3 date_subscribe if date_subscribe<=22340, color(red%70)), xline(22186 22197, lpat(dot) lcol(black)) `bgopt' legend(off) xtit("Calendar date") ylab(0(1)3,angle(0) nogrid) yline(0, lcol(black) lpat(dot)) xlab(#6, labsize(small)) text(3 22178 "Intervention" "begins", size(small) color(gray)) text(3 22210 "Due date of" "October 2020" "billing period", size(small) color(gray)) ytit(Treatment effect (p.p.)) text(0.6 22270 "T=1", size(small) color(blue%90)) text(1.2 22270 "T=2", size(small) color(black%90)) text(1.7 22270 "T=3", size(small) color(red)) aspect(0.5)
graph export "$Results\subscription-rate-TE-subgroups.pdf", replace 
restore




preserve
gen treat=1 if tratado==1
gen control=1 if tratado==0
collapse (count) treat control if boleta_digital==1, by(month)

graph bar control treat if month<=12, over(month) `bgopt' bar(1, color(black*0.2)) bar(2, color(black*0.8)) ylabel(#6, angle(horizontal)) legend(label(1 "No recibe carta (C)") label(2 "Recibe carta (T)")) ytitle("Suscripciones a boleta digital") bargap(-30) blabel(bar, position(inside) format(%9.0f) color(white)) text(400 92 "T suscribe" "mas que C")
graph export "$Results\Boletadigital.pdf", replace 

gen ratio = treat/control
twoway (connected ratio month) if month<=12

restore



**********************************************
** Saturated regressions - October 2020
**********************************************
*Jointly estimate all the parameters
*Standard errors clustered by blocks (num_cuadra)

**Rectangularize dataset 
*(to obtain a balanced daily panel)
preserve
keep id date_subscribe boleta_digital treat1 treat2 treat3 control1 control2 control3 num_cuadra
fillin id date_subscribe

*subscribed dummy (=1 after people subscribe to e-billing)
bys id: gen subscribed = sum( boleta_digital )

*assign T/C status
foreach var of varlist treat1-control3 {
  egen d`var'=max(`var'), by(id)
}
sort id num_cuadra
by id : replace num_cuadra = num_cuadra[_N]
sort id date_subscribe

*Destring num_cuadra
tab num_cuadra if missing(real(num_cuadra))
replace num_cuadra="3232" if num_cuadra=="32B"
destring num_cuadra, replace

*keep if ( date_subscribe>=mdy(6,5,2020) & date_subscribe<=mdy(12,31,2020) )
keep if ( date_subscribe>=mdy(9,16,2020) & date_subscribe<=mdy(10,31,2020) )

*unit fixed effect
gen aux = _n if date_subscribe==mdy(9,16,2020)
egen idi = max(aux), by(id)
drop aux

*date relative to start of intervention
gen t=date_subscribe-mdy(9,28,2020)
char t[omit] -1
xi i.t, pref(_T)


*Saturated regression with all groups

foreach g of varlist dtreat1 dtreat2 dtreat3 dcontrol1 dcontrol2 dcontrol3 {
foreach var of varlist _Tt_1-_Tt_46 {
  gen `g'`var' = `var'*`g'
}
}

set matsize 2000
reg subscribed dtreat1_Tt_1-dcontrol3_Tt_46 _Tt_1-_Tt_46 dtreat1 dtreat2 dtreat3 dcontrol1 dcontrol2 dcontrol3, cluster(num_cuadra)

matrix A = r(table)
*treated
matrix T1 = ( (A[1,1..11])' , (A[5,1..11])' , (A[6,1..11])' ) * 100 \ (0,0,0) \ ( (A[1,12..45])' , (A[5,12..45])' , (A[6,12..45])' ) * 100
matrix T2 = ( (A[1,46..56])' , (A[5,46..56])' , (A[6,46..56])' ) * 100 \ (0,0,0) \ ( (A[1,57..90])' , (A[5,57..90])' , (A[6,57..90])' ) * 100
matrix T3 = ( (A[1,91..101])' , (A[5,91..101])' , (A[6,91..101])' ) * 100 \ (0,0,0) \ ( (A[1,102..135])' , (A[5,102..135])' , (A[6,102..135])' ) * 100
*untreated
matrix C1 = ( (A[1,136..146])' , (A[5,136..146])' , (A[6,136..146])' ) * 100 \ (0,0,0) \ ( (A[1,147..180])' , (A[5,147..180])' , (A[6,147..180])' ) * 100
matrix C2 = ( (A[1,181..191])' , (A[5,181..191])' , (A[6,181..191])' ) * 100 \ (0,0,0) \ ( (A[1,192..225])' , (A[5,192..225])' , (A[6,192..225])' ) * 100
matrix C3 = ( (A[1,226..236])' , (A[5,226..236])' , (A[6,226..236])' ) * 100 \ (0,0,0) \ ( (A[1,237..270])' , (A[5,237..270])' , (A[6,237..270])' ) * 100
matrix R = T1,T2,T3,C1,C2,C3
svmat R
di mdy(9,16,2020)
gen xvar = _n+22173 if _n<=46
format xvar %td


**treated
twoway (rspike R2 R3 xvar, sort color(navy%40) msize(*.5)) (connected R1 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(#5) ylab(-.5(.5)1, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22185 22197, lpat(dot) lcol(black)) title("{bf:Blocks with 20% treated}", suffix) name(g1, replace) aspect(.5) text(.95 22181 "Intervention" "begins", size(medsmall) color(gray)) text(.9 22193 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\subscription-rate-DiD-treated1.pdf", replace 

twoway (rspike R5 R6 xvar, sort color(navy%40) msize(*.5)) (connected R4 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(#5) ylab(-.5(.5)1, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22185 22197, lpat(dot) lcol(black)) title("{bf:Blocks with 50% treated}", suffix) name(g2, replace) aspect(.5) text(.95 22181 "Intervention" "begins", size(medsmall) color(gray)) text(.9 22193 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\subscription-rate-DiD-treated2.pdf", replace 

twoway (rspike R8 R9 xvar, sort color(navy%40) msize(*.5)) (connected R7 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(#5) ylab(-.5(.5)1, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22185 22197, lpat(dot) lcol(black)) title("{bf:Blocks with 80% treated}", suffix) name(g3, replace) aspect(.5) text(.95 22181 "Intervention" "begins", size(medsmall) color(gray)) text(.9 22193 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\subscription-rate-DiD-treated3.pdf", replace 

twoway (line R7 xvar, color(red%70)) (line R4 xvar, color(black%70) lpat(shortdash)) (line R1 xvar, color(blue%70) lpat(dash)), `bgopt' xlabel(#5) ylab(-.5(.5)1, angle(0) nogrid) ytit("") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22185 22197, lpat(dot) lcol(black)) name(gall_t, replace) text(.95 22181 "Intervention" "begins", size(medsmall) color(gray)) text(.9 22193 "Due date of" "Oct'20 bill", color(gray)) ytit(Treatment effect (p.p.)) text(0.5 22218 "T20", color(blue%90)) text(.7 22218 "T50", color(black%90)) text(.93 22218 "T80", color(red)) aspect(0.5)
graph export "$Results\subscription-rate-DiD-treated.pdf", replace 


**untreated
twoway (rspike R11 R12 xvar, sort color(navy%40) msize(*.5)) (connected R10 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(#5) ylab(-.5(.5)1, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22185 22197, lpat(dot) lcol(black)) title("{bf:Blocks with 20% treated}", suffix) name(g1, replace) aspect(.5) text(.95 22181 "Intervention" "begins", size(medsmall) color(gray)) text(.9 22193 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\subscription-rate-DiD-untreated1.pdf", replace 

twoway (rspike R14 R15 xvar, sort color(navy%40) msize(*.5)) (connected R13 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(#5) ylab(-.5(.5)1, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22185 22197, lpat(dot) lcol(black)) title("{bf:Blocks with 50% treated}", suffix) name(g2, replace) aspect(.5) text(.95 22181 "Intervention" "begins", size(medsmall) color(gray)) text(.9 22193 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\subscription-rate-DiD-untreated2.pdf", replace 

twoway (rspike R17 R18 xvar, sort color(navy%40) msize(*.5)) (connected R16 xvar, msy(o) mcol(navy) lcol(navy) mlcol(navy)), `bgopt' xlabel(#5) ylab(-.5(.5)1, angle(0) nogrid) ytit("Treatment effect (p.p.)") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22185 22197, lpat(dot) lcol(black)) title("{bf:Blocks with 80% treated}", suffix) name(g3, replace) aspect(.5) text(.95 22181 "Intervention" "begins", size(medsmall) color(gray)) text(.9 22193 "Due date of" "Oct'20 bill", color(gray))
graph export "$Results\subscription-rate-DiD-untreated3.pdf", replace 

twoway (line R16 xvar, color(red%70)) (line R13 xvar, color(black%70) lpat(shortdash)) (line R10 xvar, color(blue%70) lpat(dash)), `bgopt' xlabel(#5) ylab(-.5(.5)1, angle(0) nogrid) ytit("") xtit("Calendar date") yline(0, lcol(maroon) lpat(dash)) legend(off) xline(22185 22197, lpat(dot) lcol(black)) name(gall_u, replace) text(.95 22181 "Intervention" "begins", size(medsmall) color(gray)) text(.9 22193 "Due date of" "Oct'20 bill", color(gray)) ytit(Treatment effect (p.p.)) text(-0.2 22218 "T20", color(blue%90)) text(.3 22218 "T50", color(black%90)) text(0 22218 "T80", color(red)) aspect(0.5)
graph export "$Results\subscription-rate-DiD-untreated.pdf", replace 

drop R1-xvar


*******************
** Table
*******************
*Subscription rate on 9/27/2020 (check: this should be the constant of every regression)
summ subscribed if dtreat1==0 & dtreat2==0 & dtreat3==0 & dcontrol1==0 & dcontrol2==0 & dcontrol3==0 & date_subscribe==mdy(9,27,2020)

replace subscribed = subscribed*100

*regressions: (i) pre, (ii) early, (iii) by due date, (iv) by 31 Oct
foreach d of numlist 5 18 24 46 {

  gen inter_treat1 = dtreat1_Tt_`d' 
  gen inter_treat2 = dtreat2_Tt_`d' 
  gen inter_treat3 = dtreat3_Tt_`d' 
  gen inter_control1 = dcontrol1_Tt_`d' 
  gen inter_control2 = dcontrol2_Tt_`d' 
  gen inter_control3 = dcontrol3_Tt_`d'

  if `d'==5 local date=mdy(9,20,2020)
  if `d'==18 local date=mdy(10,3,2020)
  if `d'==24 local date=mdy(10,9,2020)
  if `d'==46 local date=mdy(10,31,2020)

  reg subscribed inter_treat1 inter_treat2 inter_treat3 inter_control1 inter_control2 inter_control3 _Tt_`d' dtreat1 dtreat2 dtreat3 dcontrol1 dcontrol2 dcontrol3 if (date_subscribe==mdy(9,27,2020) | date_subscribe==`date'), cluster(num_cuadra)
  estimates store reg`d'
  estadd scalar cons = _b[_cons]
  drop inter_treat1-inter_control3

}

local options_estout "keep(inter_treat1 inter_treat2 inter_treat3 inter_control1 inter_control2 inter_control3) coeflabel(inter_treat1 "\hspace{0.1cm} Treated" inter_treat2 "\hspace{0.1cm} Treated" inter_treat3 "\hspace{0.1cm} Treated" inter_control1 "\hspace{0.1cm} Untreated" inter_control2 "\hspace{0.1cm} Untreated" inter_control3 "\hspace{0.1cm} Untreated") refcat(inter_treat1 "\emph{\textbf{C. Blocks with 20\% treated}}" inter_treat2 "\emph{\textbf{B. Blocks with 50\% treated}}" inter_treat3 "\emph{\textbf{A. Blocks with 80\% treated}}", nolabel) order(inter_treat3 inter_control3 inter_treat2 inter_control2 inter_treat1 inter_control1) substitute(\_ _) se star(* 0.10 ** 0.05 *** 0.01) nonotes collabels(none) eqlabels(none) mlabels(none) mgroups(none) cells((b(star fmt(2))) (se(fmt(2)par))) stats(cons N N_clust, fmt(2 %9.0fc) labels("Mean of Pure Control at baseline" "Observations" "Number of clusters (blocks)")) replace noconstant"

esttab reg5 reg18 reg46 using "$Results\saturated_regressions_ebill_2.tex", `options_estout' booktabs title(Total effects and spillover effects for subscriptions to e-billing) prehead("\begin{table}[H]\centering" "\small" "\caption{@title}" "\label{table_ebill}" "\begin{center}" "\begin{threeparttable}" "\begin{tabularx}{\textwidth}{l Y Y Y}" "\toprule" "\multicolumn{1}{l}{\textbf{Dependent variable:}}&" "\multicolumn{1}{c}{\textbf{Placebo:}}&" "\multicolumn{2}{c}{\textbf{Intervention:}}\\" "\multicolumn{1}{l}{Pr(subscribe to e-bill)}&" "\multicolumn{1}{c}{By Sep 20}&" "\multicolumn{1}{c}{Early}&" "\multicolumn{1}{c}{By Oct 31}\\" "\cline{3-4}") posthead("\midrule") prefoot("\midrule") postfoot("\bottomrule" "\end{tabularx}" "\begin{tablenotes}[flushleft]" "\footnotesize" "Notes: This table shows the results from a saturated dynamic difference-in-differences regression where the dependent variable is an indicator for subscribing to electronic billing. The regression computes the outcome difference between each of the treated and untreated groups relative to the pure control group for each calendar date relative to September 27th, 2020 (baseline date). The estimates correspond exactly to the numbers shown in Figure (\ref{figure:subscriptions_DD}). Column (1) shows the results for e-bill subscriptions made before the letters were delivered (placebo); Column (2) shows the results for early subscriptions right after the letters started to be delivered (by October 3); Column (3) shows the results for subscriptions made up to the end of October 2020. The letters were delivered between September 28 and October 7. The due date for the October 2020 bill was October 9th. The row \emph{Mean of Pure Control} displays the constant of the regression, corresponding to the average susbcription rate for units in blocks with no treated units on September 27, 2020. Standard errors clustered by blocks are reported in parentheses. * p$<$0.10, ** p$<$0.05, *** p$<$0.01" "\end{tablenotes}" \end{threeparttable} \end{center} \end{table}) 

restore


