** Robustness - GIS analysis
local bgopt "plotregion(icolor(white)) graphregion(fcolor(white) color(white)) bgcolor(white)"

*Open working database
use working_data.dta, clear
tab T tratado if periodo==202010

*Merge with GIS database containing intensity of treatment for different buffers
tostring num_cuadra, replace
merge m:1 num_cuadra using cuadras_buffers.dta, keepusing(cuads_t0_100 vivs_t0_100 cuads_t1_100 vivs_t1_100 cuads_t2_100 vivs_t2_100 cuads_t3_100 vivs_t3_100 cuads_all_100 vivs_all_100 cuads_nan_100 vivs_nan_100 vivs_t0_200 vivs_t1_200 vivs_t2_200 vivs_t3_200 vivs_all_200 vivs_t0_300 vivs_t1_300 vivs_t2_300 vivs_t3_300 vivs_all_300) keep(master match)

gen aux = tratado if periodo==202010
egen N_treated = total(aux), by(num_cuadra)
egen N_vivs = count(aux), by(num_cuadra)
drop aux

*Exposure measures for buffers of 100, 200, 300 meters
gen intensity_treatment = (0.2*vivs_t1_100 + 0.5*vivs_t2_100 + 0.8*vivs_t3_100) / vivs_all_100
gen intensity_treatment100 = (0.2*vivs_t1_100 + 0.5*vivs_t2_100 + 0.8*vivs_t3_100 - N_treated) / vivs_all_100
gen intensity_treatment200 = (0.2*vivs_t1_200 + 0.5*vivs_t2_200 + 0.8*vivs_t3_200 - N_treated) / vivs_all_200
gen intensity_treatment300 = (0.2*vivs_t1_300 + 0.5*vivs_t2_300 + 0.8*vivs_t3_300 - N_treated) / vivs_all_300


*Distribution of the exposure measure (pure control accounts)
twoway (hist intensity_treatment100 if periodo==202010 & T==0, frac color(gs10%70)), xlabels(0(.1).8) ylab(, angle(0)) `bgopt' xtitle(Share of treated accounts around pure control blocks, size(small)) xsize(4) subtitle("Share of" "accounts", placement(7) span) ytit("") text(.09 .4 "{bf:100mts buffer}", size(large))
graph export "$Results\buffer_share_T100.pdf", replace
twoway (hist intensity_treatment200 if periodo==202010 & T==0, frac color(gs10%70)), xlabels(0(.1).8) ylab(, angle(0)) `bgopt' xtitle(Share of treated accounts around pure control blocks, size(small)) xsize(4) subtitle("Share of" "accounts", placement(7) span) ytit("") text(.09 .4 "{bf:200mts buffer}", size(large))
graph export "$Results\buffer_share_T200.pdf", replace
twoway (hist intensity_treatment300 if periodo==202010 & T==0, frac color(gs10%70)), xlabels(0(.1).8) ylab(, angle(0)) `bgopt' xtitle(Share of treated accounts around pure control blocks, size(small)) xsize(4) subtitle("Share of" "accounts", placement(7) span) ytit("") text(.09 .4 "{bf:300mts buffer}", size(large))
graph export "$Results\buffer_share_T300.pdf", replace

_pctile intensity_treatment300 if periodo==202010 & T==0, nq(4)
ret list

*Generate cuadratic and cubic controls
gen vivs_100_2 = vivs_all_100*vivs_all_100
gen vivs_100_3 = vivs_all_100*vivs_all_100*vivs_all_100
gen vivs_200_2 = vivs_all_200*vivs_all_200
gen vivs_200_3 = vivs_all_200*vivs_all_200*vivs_all_200
gen vivs_300_2 = vivs_all_300*vivs_all_300
gen vivs_300_3 = vivs_all_300*vivs_all_300*vivs_all_300

*******************************************************
*Pure control blocks: 100, 200, 300 mts (October 2020)
*******************************************************
reg pago_cuota_oct20 intensity_treatment100 vivs_all_100 vivs_100_2 vivs_100_3 if periodo==202010 & T==0
reg pago_cuota_oct20 intensity_treatment100 if periodo==202010 & T==0
gen emuestra = e(sample)
binscatter pago_cuota_oct20 intensity_treatment100 if periodo==202010 & T==0, ylab(0.20(.05).50, nogrid) control(vivs_all_100 vivs_100_2 vivs_100_3) xlab(0.05(.1).55) xtitle(Exposure: 100mts) xsize(4) subtitle("Payment" "rate", placement(7) span) ytit("") name(g1, replace) text(.47 .45 "{bf:b=.000}" "{bf:(p=.979)}", size(large)) text(.52 .3 "{bf:100mts buffer}", size(large)) `bgopt'
graph export "$Results\buffer_T0_100.pdf", replace

reg pago_cuota_oct20 intensity_treatment200 vivs_all_200 vivs_200_2 vivs_200_3 if periodo==202010 & T==0 & emuestra==1
reg pago_cuota_oct20 intensity_treatment200 vivs_all_200 if periodo==202010 & T==0 & emuestra==1
binscatter pago_cuota_oct20 intensity_treatment200 if periodo==202010 & T==0 & emuestra==1, ylab(0.20(.05).50, nogrid) control(vivs_all_200 vivs_200_2 vivs_200_3) xlab(0.05(.1).55) xtitle(Exposure: 200mts) xsize(4) subtitle("Payment" "rate", placement(7) span) ytit("") name(g2, replace) text(.47 .45 "{bf:b=.049}" "{bf:(p=.271)}", size(large)) text(.52 .3 "{bf:200mts buffer}", size(large)) `bgopt'
graph export "$Results\buffer_T0_200.pdf", replace

reg pago_cuota_oct20 intensity_treatment300 vivs_all_300 vivs_300_2 vivs_300_3 if periodo==202010 & T==0 & emuestra==1
reg pago_cuota_oct20 intensity_treatment300 vivs_all_300 if periodo==202010 & T==0 & emuestra==1
binscatter pago_cuota_oct20 intensity_treatment300 if periodo==202010 & T==0 & emuestra==1, ylab(0.20(.05).50, nogrid) control(vivs_all_300 vivs_300_2 vivs_300_3) xlab(0.05(.1).55) xtitle(Exposure: 300mts) xsize(4) subtitle("Payment" "rate", placement(7) span) ytit("") name(g3, replace) text(.47 .45 "{bf:b=.008}" "{bf:(p=.881)}", size(large)) text(.52 .3 "{bf:300mts buffer}", size(large)) `bgopt'
graph export "$Results\buffer_T0_300.pdf", replace

*******************************************************
*Compare T=0 vs T=3 (100mts)
*In October 2020
*and Pre-intervention
*******************************************************
binscatter pago_cuota_oct20 intensity_treatment100 if periodo==202010 & (T==0 | T==3), ylab(0.25(.05).5, nogrid) xlab(0.05(.1).55) control(vivs_all_100 vivs_100_2 vivs_100_3) xtitle(Exposure: 100mts) xsize(4) subtitle("Payment" "rate", placement(7) span) ytit("") by(T) msy(O t) mcol(navy maroon*.5) name(g1, replace) legend(off) text(.42 .45 "Blocks with" "80% treated", color(maroon) size(large)) text(.32 .45 "Untreated" "blocks", color(navy) size(large)) `bgopt' text(.52 .3 "{bf:October 2020}", size(large))
graph export "$Results\buffer_T0T3_100.pdf", replace

binscatter pago_cuota_pre intensity_treatment100 if periodo==202008 & (T==0 | T==3), ylab(0.25(.05).5, nogrid) xlab(0.05(.1).55) control(vivs_all_100 vivs_100_2 vivs_100_3) xtitle(Exposure: 100mts) xsize(4) subtitle("Payment" "rate", placement(7) span) ytit("") by(T) msy(O t) mcol(navy maroon*.5) name(g1, replace) legend(off) `bgopt' text(.52 .3 "{bf:August 2020}" "Pre intervention", size(large))
graph export "$Results\buffer_T0T3_100_aug.pdf", replace

binscatter pago_cuota_pre intensity_treatment100 if periodo==202007 & (T==0 | T==3), ylab(0.25(.05).5, nogrid) xlab(0.05(.1).55) control(vivs_all_100 vivs_100_2 vivs_100_3) xtitle(Exposure: 100mts) xsize(4) subtitle("Payment" "rate", placement(7) span) ytit("") by(T) msy(O t) mcol(navy maroon*.5) name(g1, replace) legend(off) `bgopt' text(.52 .3 "{bf:July 2020}" "Pre intervention", size(large))
graph export "$Results\buffer_T0T3_100_jul.pdf", replace

*******************************************************
*Blocks below and above median compliance in 2019 (100mts)
*******************************************************
egen tag = tag(num_cuadra) if periodo==202010
gen aux2019=pago_cuota_pre if anio==2019
egen share_block_2019 = mean(aux2019), by(num_cuadra)
drop aux2019

_pctile share_block_2019 if tag==1, nq(2)
ret list
loc median=r(r1)

gen above_median = share_block_2019 > `median' 

reg pago_cuota_oct20 intensity_treatment100 vivs_all_100 vivs_100_2 vivs_100_3 if periodo==202010 & T==0
reg pago_cuota_oct20 intensity_treatment100 vivs_all_100 vivs_100_2 vivs_100_3 if periodo==202010 & T==0 & above_median==1
reg pago_cuota_oct20 intensity_treatment100 vivs_all_100 vivs_100_2 vivs_100_3 if periodo==202010 & T==0 & above_median==0

binscatter pago_cuota_oct20 intensity_treatment100 if periodo==202010 & T==0, ylab(0.15(.05).55, nogrid) control(vivs_all_100 vivs_100_2 vivs_100_3) xlab(0.05(.1).55) xtitle(Exposure: 100mts) xsize(4) subtitle("Payment" "rate", placement(7) span) ytit("") name(g1, replace) text(.47 .45 "{bf:b=.000}" "{bf:(p=.979)}", size(large)) text(.6 .3 "{bf:All}", size(large)) `bgopt'
graph export "$Results\buffer_T0_100_pool.pdf", replace

binscatter pago_cuota_oct20 intensity_treatment100 if periodo==202010 & T==0 & above_median==1, ylab(0.15(.05).55, nogrid) control(vivs_all_100 vivs_100_2 vivs_100_3) xlab(0.05(.1).55) xtitle(Exposure: 100mts) xsize(4) subtitle("Payment" "rate", placement(7) span) ytit("") name(g1, replace) text(.52 .45 "{bf:b=-0.018}" "{bf:(p=0.687)}", size(large)) text(.6 .3 "Above Median" "Compliance", size(large) col(green)) `bgopt' color(green) lcolor(black)
graph export "$Results\buffer_T0_100_abovep50.pdf", replace

binscatter pago_cuota_oct20 intensity_treatment100 if periodo==202010 & T==0 & above_median==0, ylab(0.15(.05).55, nogrid) control(vivs_all_100 vivs_100_2 vivs_100_3) xlab(0.05(.1).55) xtitle(Exposure: 100mts) xsize(4) subtitle("Payment" "rate", placement(7) span) ytit("") name(g1, replace) text(.32 .45 "{bf:b=-0.013}" "{bf:(p=0.745)}", size(large)) text(.6 .3 "Below Median" "Compliance", size(large) col(red*.5)) `bgopt' color(red*.5) lcolor(black)
graph export "$Results\buffer_T0_100_belowp50.pdf", replace



